@@ -45,19 +45,19 @@ void convlog(const char *arq, char *df, int dfrom, int duntil)
 	if (arq[0]=='-' && arq[1]=='\0') {
 		fp_in=stdin;
 	} else if((fp_in=MY_FOPEN(arq,"r"))==NULL) {
-		debuga(_("(convlog) Cannot open log file %s - %s\n"),arq,strerror(errno));
+		debugapos("convlog",_("Cannot open file \"%s\": %s\n"),arq,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if ((line=longline_create())==NULL) {
-		debuga(_("Not enough memory to read the log file %s\n"),arq);
+		debuga(_("Not enough memory to read file \"%s\"\n"),arq);
 		exit(EXIT_FAILURE);
 	}
 
 	while((buf=longline_read(fp_in,line))!=NULL) {
 		getword_start(&gwarea,buf);
 		if (getword(data,sizeof(data),&gwarea,' ')<0) {
-			debuga(_("Maybe you have a broken record or garbage in file %s\n"),arq);
+			debuga(_("Invalid record in file \"%s\"\n"),arq);
 			exit(EXIT_FAILURE);
 		}
 		tt=atoi(data);
@@ -79,6 +79,6 @@ void convlog(const char *arq, char *df, int dfrom, int duntil)
 
 	longline_destroy(&line);
 	if (fp_in!=stdin && fclose(fp_in)==EOF) {
-		debuga(_("Failed to close file %s - %s\n"),arq,strerror(errno));
+		debuga(_("Failed to close file \"%s\": %s\n"),arq,strerror(errno));
 	}
 }
