@@ -52,18 +52,13 @@ void dansguardian_log(void)
 	snprintf(guard_in,sizeof(guard_in),"%s/dansguardian.int_unsort",tmp);
 	snprintf(guard_ou,sizeof(guard_ou),"%s/dansguardian.int_log",tmp);
 
-	if(access(DansGuardianConf, R_OK) != 0) {
-		debuga(_("Cannot open DansGuardian config file: %s\n"),DansGuardianConf);
-		exit(EXIT_FAILURE);
-	}
-
 	if((fp_guard=fopen(DansGuardianConf,"r"))==NULL) {
-		debuga(_("(dansguardian) Cannot open log file: %s\n"),DansGuardianConf);
+		debugapos("dansguardian",_("Cannot open file \"%s\": %s\n"),DansGuardianConf,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if((fp_ou=MY_FOPEN(guard_in,"a"))==NULL) {
-		debuga(_("(dansguardian) Cannot open log file: %s\n"),guard_in);
+		debugapos("dansguardian",_("Cannot open file \"%s\": %s\n"),guard_in,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -74,7 +69,7 @@ void dansguardian_log(void)
 		if(strstr(buf,"loglocation ") != 0) {
 			getword_start(&gwarea,buf);
 			if (getword_skip(MAXLEN,&gwarea,'\'')<0 || getword(loglocation,sizeof(loglocation),&gwarea,'\'')<0) {
-				debuga(_("Maybe you have a broken record or garbage in your %s file\n"),DansGuardianConf);
+				debuga(_("Invalid record in file \"%s\"\n"),DansGuardianConf);
 				exit(EXIT_FAILURE);
 			}
 			if (debug) debuga(_("Using the dansguardian log file \"%s\" found in your configuration file \"%s\"\n"),
@@ -84,10 +79,10 @@ void dansguardian_log(void)
 	}
 
 	if(debug)
-		debuga(_("Reading DansGuardian log file: %s\n"),loglocation);
+		debuga(_("Reading DansGuardian log file \"%s\"\n"),loglocation);
 
 	if((fp_in=MY_FOPEN(loglocation,"r"))==NULL) {
-		debuga(_("(dansguardian) Cannot open log file: %s\n"),loglocation);
+		debugapos("dansguardian",_("Cannot open file \"%s\": %s\n"),loglocation,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -97,32 +92,32 @@ void dansguardian_log(void)
 		getword_start(&gwarea,buf);
 		if (getword_atoi(&year,&gwarea,'.')<0 || getword_atoi(&mon,&gwarea,'.')<0 ||
 		    getword_atoi(&day,&gwarea,' ')<0) {
-			debuga(_("Invalid date found in your dansguardian log file %s\n"),loglocation);
+			debuga(_("Invalid date in file \"%s\"\n"),loglocation);
 			exit(EXIT_FAILURE);
 		}
 		if (getword_atoi(&hour,&gwarea,':')<0 || getword(minsec,sizeof(minsec),&gwarea,' ')<0) {
-			debuga(_("Invalid time found in your dansguardian log file %s\n"),loglocation);
+			debuga(_("Invalid time in file \"%s\"\n"),loglocation);
 			exit(EXIT_FAILURE);
 		}
 		if (getword(user,sizeof(user),&gwarea,' ')<0) {
-			debuga(_("Invalid user found in your dansguardian log file %s\n"),loglocation);
+			debuga(_("Invalid user in file \"%s\"\n"),loglocation);
 			exit(EXIT_FAILURE);
 		}
 		if (getword(ip,sizeof(ip),&gwarea,' ')<0) {
-			debuga(_("Invalid IP address found in your dansguardian log file %s\n"),loglocation);
+			debuga(_("Invalid IP address in file \"%s\"\n"),loglocation);
 			exit(EXIT_FAILURE);
 		}
 		if (getword_skip(MAXLEN,&gwarea,'/')<0 || getword_skip(MAXLEN,&gwarea,'/')<0) {
-			debuga(_("Maybe you have a broken record or garbage in your %s file\n"),loglocation);
+			debuga(_("Invalid record in file \"%s\"\n"),loglocation);
 			exit(EXIT_FAILURE);
 		}
 		if (getword_ptr(buf,&url,&gwarea,' ')<0) {
-			debuga(_("Maybe you have a broken url in your %s file\n"),loglocation);
+			debuga(_("Invalid url in file \"%s\"\n"),loglocation);
 			exit(EXIT_FAILURE);
 		}
 		if (getword_skip(255,&gwarea,' ')<0 ||
 		    getword(code1,sizeof(code1),&gwarea,' ')<0 || getword(code2,sizeof(code2),&gwarea,' ')<0) {
-			debuga(_("Maybe you have a broken record or garbage in your %s file\n"),loglocation);
+			debuga(_("Invalid record in file \"%s\"\n"),loglocation);
 			exit(EXIT_FAILURE);
 		}
 		idata = year*10000+mon*100+day;
@@ -145,7 +140,7 @@ void dansguardian_log(void)
 	if(fp_ou) fclose(fp_ou);
 
 	if(debug)
-		debuga(_("Sorting file: %s\n"),guard_ou);
+		debuga(_("Sorting file \"%s\"\n"),guard_ou);
 
 	snprintf(tmp6,sizeof(tmp6),"sort -t \"\t\" -k 1,1 -k 2,2 -k 4,4 \"%s\" -o \"%s\"",guard_in, guard_ou);
 	cstatus=system(tmp6);
