@@ -69,12 +69,12 @@ void dansguardian_report(void)
 	sprintf(report,"%s/dansguardian.html",outdirname);
 
 	if((fp_in=MY_FOPEN(dansguardian_in,"r"))==NULL) {
-		debuga(_("(dansguardian_report) Cannot open log file %s\n"),dansguardian_in);
+		debugapos("dansguardian_report",_("Cannot open file \"%s\": %s\n"),dansguardian_in,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if((fp_ou=MY_FOPEN(report,"w"))==NULL) {
-		debuga(_("(dansguardian_report) Cannot open log file %s\n"),report);
+		debugapos("dansguardian_report",_("Cannot open file \"%s\": %s\n"),report,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -92,15 +92,15 @@ void dansguardian_report(void)
 		getword_start(&gwarea,buf);
 		if (getword(user,sizeof(user),&gwarea,'\t')<0 || getword(date2,sizeof(date2),&gwarea,'\t')<0 ||
 		    getword(hour,sizeof(hour),&gwarea,'\t')<0 || getword(ip,sizeof(ip),&gwarea,'\t')<0) {
-			debuga(_("Maybe you have a broken record or garbage in your %s file\n"),dansguardian_in);
+			debuga(_("Invalid record in file \"%s\"\n"),dansguardian_in);
 			exit(EXIT_FAILURE);
 		}
 		if (getword_ptr(buf,&url,&gwarea,'\t')<0) {
-			debuga(_("Maybe you have a broken url in your %s file\n"),dansguardian_in);
+			debuga(_("Invalid url in file \"%s\"\n"),dansguardian_in);
 			exit(EXIT_FAILURE);
 		}
 		if (getword(rule,sizeof(rule),&gwarea,'\n')<0) {
-			debuga(_("Maybe you have a broken rule in your %s file\n"),dansguardian_in);
+			debuga(_("Invalid rule in file \"%s\"\n"),dansguardian_in);
 			exit(EXIT_FAILURE);
 		}
 
@@ -166,9 +166,9 @@ void dansguardian_report(void)
 
 	fputs("</table></div>\n",fp_ou);
 	if (write_html_trailer(fp_ou)<0)
-		debuga(_("Write error in file %s\n"),report);
+		debuga(_("Write error in file \"%s\"\n"),report);
 	if (fclose(fp_ou)==EOF)
-		debuga(_("Failed to close file %s - %s\n"),report,strerror(errno));
+		debuga(_("Failed to close file \"%s\": %s\n"),report,strerror(errno));
 
 	if (!KeepTempLog && unlink(dansguardian_in)) {
 		debuga(_("Cannot delete \"%s\": %s\n"),dansguardian_in,strerror(errno));
