@@ -33,15 +33,16 @@ FILE *decomp(const char *arq, bool *pipe)
 	int arqlen;
 
 	if(access(arq, R_OK) != 0) {
-		debuga(_("File not found: %s\n"),arq);
+		debuga(_("File \"%s\" not found\n"),arq);
 		exit(EXIT_FAILURE);
 	}
 
 	arqlen=strlen(arq);
 	if(arqlen>3 && strcmp(arq+arqlen-3,".gz") == 0) {
-		debuga(_("Decompressing log file \"%s\" with zcat\n"),arq);
+		/* TRANSLATORS: The last %s is the decompression program such as zcat or bzcat */
+		debuga(_("Decompressing log file \"%s\" with %s\n"),arq,"zcat");
 		if (snprintf(cmd,sizeof(cmd),"zcat \"%s\"",arq)>=sizeof(cmd)) {
-			debuga(_("decompression command too long for log file %s\n"),arq);
+			debuga(_("Decompression command too long for log file \"%s\"\n"),arq);
 			exit(EXIT_FAILURE);
 		}
 		*pipe=true;
@@ -49,9 +50,9 @@ FILE *decomp(const char *arq, bool *pipe)
 	}
 
 	if(arqlen>4 && strcmp(arq+arqlen-4,".bz2") == 0) {
-		debuga(_("Decompressing log file \"%s\" with bzcat\n"),arq);
+		debuga(_("Decompressing log file \"%s\" with %s\n"),arq,"bzcat");
 		if (snprintf(cmd,sizeof(cmd),"bzcat \"%s\"",arq)>=sizeof(cmd)) {
-			debuga(_("decompression command too long for log file %s\n"),arq);
+			debuga(_("Decompression command too long for log file \"%s\"\n"),arq);
 			exit(EXIT_FAILURE);
 		}
 		*pipe=true;
@@ -59,9 +60,9 @@ FILE *decomp(const char *arq, bool *pipe)
 	}
 
 	if(arqlen>2 && strcmp(arq+arqlen-2,".Z") == 0) {
-		debuga(_("Decompressing log file \"%s\" with zcat\n"),arq);
+		debuga(_("Decompressing log file \"%s\" with %s\n"),arq,"zcat");
 		if (snprintf(cmd,sizeof(cmd),"zcat \"%s\"",arq)>=sizeof(cmd)) {
-			debuga(_("decompression command too long for log file %s\n"),arq);
+			debuga(_("Decompression command too long for log file \"%s\"\n"),arq);
 			exit(EXIT_FAILURE);
 		}
 		*pipe=true;
