@@ -62,7 +62,9 @@ static void download_sort(const char *report_in)
 	clen=snprintf(csort,sizeof(csort),"sort -T \"%s\" -t \"\t\" -k 3,3 -k 1,1 -k 2,2 -k 5,5 -o \"%s\" \"%s/download.int_unsort\"",
 			tmp, report_in, tmp);
 	if (clen>=sizeof(csort)) {
-		debuga(_("Path too long to sort the file: %s/download.int_unsort\n"),tmp);
+		debuga(_("Command too long: "));
+		debuga_more("sort -T \"%s\" -t \"\t\" -k 3,3 -k 1,1 -k 2,2 -k 5,5 -o \"%s\" \"%s/download.int_unsort\"",
+					tmp, report_in, tmp);
 		exit(EXIT_FAILURE);
 	}
 	cstatus=system(csort);
@@ -72,7 +74,8 @@ static void download_sort(const char *report_in)
 		exit(EXIT_FAILURE);
 	}
 	if (snprintf(csort,sizeof(csort),"%s/download.int_unsort",tmp)>=sizeof(csort)) {
-		debuga(_("Path too long for %s/download.int_unsort\n"),tmp);
+		debuga(_("Path too long: "));
+		debuga_more("%s/download.int_unsort\n",tmp);
 		exit(EXIT_FAILURE);
 	}
 	if (!KeepTempLog && unlink(csort)) {
@@ -130,12 +133,12 @@ void download_report(void)
 	snprintf(report,sizeof(report),"%s/download.html",outdirname);
 
 	if((fp_in=MY_FOPEN(report_in,"r"))==NULL) {
-		debuga(_("(download) Cannot open log file %s\n"),report_in);
+		debugapos("download",_("Cannot open file \"%s\": %s\n"),report_in,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if((fp_ou=MY_FOPEN(report,"w"))==NULL) {
-		debuga(_("(download) Cannot open log file %s\n"),report);
+		debugapos("download",_("Cannot open file \"%s\": %s\n"),report,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -150,7 +153,7 @@ void download_report(void)
 	fprintf(fp_ou,"<tr><th class=\"header_l\">%s</th><th class=\"header_l\">%s</th><th class=\"header_l\">%s</th><th class=\"header_l\">%s</th></tr>\n",_("USERID"),_("IP/NAME"),_("DATE/TIME"),_("ACCESSED SITE"));
 
 	if ((line=longline_create())==NULL) {
-		debuga(_("Not enough memory to read the downloaded files\n"));
+		debuga(_("Not enough memory to read file \"%s\"\n"),report_in);
 		exit(EXIT_FAILURE);
 	}
 
@@ -158,11 +161,11 @@ void download_report(void)
 		getword_start(&gwarea,buf);
 		if (getword(data,sizeof(data),&gwarea,'\t')<0 || getword(hora,sizeof(hora),&gwarea,'\t')<0 ||
 		    getword(user,sizeof(user),&gwarea,'\t')<0 || getword(ip,sizeof(ip),&gwarea,'\t')<0) {
-			debuga(_("There is a broken record or garbage in file %s\n"),report_in);
+			debuga(_("Invalid record in file \"%s\"\n"),report_in);
 			exit(EXIT_FAILURE);
 		}
 		if (getword_ptr(buf,&url,&gwarea,'\t')<0) {
-			debuga(_("There is a broken url in file %s\n"),report_in);
+			debuga(_("Invalid url in file \"%s\"\n"),report_in);
 			exit(EXIT_FAILURE);
 		}
 		if (sscanf(data,"%d/%d/%d",&day,&month,&year)!=3) continue;
@@ -171,7 +174,7 @@ void download_report(void)
 
 		uinfo=userinfo_find_from_id(user);
 		if (!uinfo) {
-			debuga(_("Unknown user ID %s in file %s\n"),user,report_in);
+			debuga(_("Unknown user ID %s in file \"%s\"\n"),user,report_in);
 			exit(EXIT_FAILURE);
 		}
 		new_user=false;
@@ -226,9 +229,9 @@ void download_report(void)
 
 	fputs("</table></div>\n",fp_ou);
 	if (write_html_trailer(fp_ou)<0)
-		debuga(_("Write error in file %s\n"),report);
+		debuga(_("Write error in file \"%s\"\n"),report);
 	if (fclose(fp_ou)==EOF)
-		debuga(_("Failed to close file %s - %s\n"),report,strerror(errno));
+		debuga(_("Failed to close file \"%s\": %s\n"),report,strerror(errno));
 
 	if (!KeepTempLog && unlink(report_in)) {
 		debuga(_("Cannot delete \"%s\": %s\n"),report_in,strerror(errno));
