@@ -58,19 +58,19 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
 
 	snprintf(wger,sizeof(wger),"%s/sarg-general",dirname);
 	if((fp_in=fopen(wger,"r"))==NULL) {
-		debuga(_("(email) Cannot open file %s\n"),wger);
+		debugapos("email",_("Cannot open file \"%s\": %s\n"),wger,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	snprintf(top1,sizeof(top1),"%s/top",dirname);
 	if((fp_top1=fopen(top1,"w"))==NULL) {
-		debuga(_("(email) Cannot open file %s\n"),top1);
+		debugapos("email",_("Cannot open file \"%s\": %s\n"),top1,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	snprintf(top2,sizeof(top2),"%s/top.tmp",dirname);
 	if((fp_top2=fopen(top2,"w"))==NULL) {
-		debuga(_("(email) Cannot open file %s\n"),top2);
+		debugapos("email",_("Cannot open file \"%s\": %s\n"),top2,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -78,7 +78,7 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
 	totuser=0;
 
 	if ((line=longline_create())==NULL) {
-		debuga(_("Not enough memory to read file %s\n"),wger);
+		debuga(_("Not enough memory to read file \"%s\"\n"),wger);
 		exit(EXIT_FAILURE);
 	}
 
@@ -132,7 +132,8 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
 #endif
 
 	if (snprintf(csort,sizeof(csort),"sort -n -T \"%s\" -t \"\t\" -r -k 2,2 -o \"%s\" \"%s\"", TempDir, top1, top2)>=sizeof(csort)) {
-		debuga(_("Sort command too long when sorting file \"%s\" to \"%s\"\n"),top2,top1);
+		debuga(_("Command too long: "));
+		debuga_more("sort -n -T \"%s\" -t \"\t\" -r -k 2,2 -o \"%s\" \"%s\"", TempDir, top1, top2);
 		exit(EXIT_FAILURE);
 	}
 	cstatus=system(csort);
@@ -148,13 +149,13 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
 	}
 
 	if((fp_top1=fopen(top1,"r"))==NULL) {
-		debuga(_("(email) Cannot open file %s\n"),top1);
+		debugapos("email",_("Cannot open file \"%s\": %s\n"),top1,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	snprintf(top3,sizeof(top3),"%s/report",dirname);
 	if((fp_top3=fopen(top3,"w"))==NULL) {
-		debuga(_("(email) Cannot open file %s\n"),top3);
+		debugapos("email",_("Cannot open file \"%s\": %s\n"),top3,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -191,25 +192,25 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
 		fixendofline(warea);
 		getword_start(&gwarea,warea);
 		if (getword(user,sizeof(user),&gwarea,'\t')<0) {
-			debuga(_("There is an invalid user ID in file %s\n"),top1);
+			debuga(_("Invalid user ID in file \"%s\"\n"),top1);
 			exit(EXIT_FAILURE);
 		}
 		if (getword_atoll(&nbytes,&gwarea,'\t')<0) {
-			debuga(_("There is an invalid number of bytes in file %s\n"),top1);
+			debuga(_("Invalid number of bytes in file \"%s\"\n"),top1);
 			exit(EXIT_FAILURE);
 		}
 		if (getword_atoll(&nacc,&gwarea,'\t')<0) {
-			debuga(_("There is an invalid number of access in file %s\n"),top1);
+			debuga(_("Invalid number of accesses in file \"%s\"\n"),top1);
 			exit(EXIT_FAILURE);
 		}
 		if (getword_atoll(&elap,&gwarea,'\0')<0) {
-			debuga(_("There is an invalid elapsed time in file %s\n"),top1);
+			debuga(_("Invalid elapsed time in file \"%s\"\n"),top1);
 			exit(EXIT_FAILURE);
 		}
 
 		uinfo=userinfo_find_from_id(user);
 		if (!uinfo) {
-			debuga(_("Unknown user ID %s in file %s\n"),user,top1);
+			debuga(_("Unknown user ID %s in file \"%s\"\n"),user,top1);
 			exit(EXIT_FAILURE);
 		}
 
@@ -266,7 +267,7 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
 
 	if(strcmp(email,"stdout") == 0) {
 		if((fp_top3=fopen(top3,"r"))==NULL) {
-			debuga(_("(email) Cannot open file %s\n"),top3);
+			debugapos("email",_("Cannot open file \"%s\": %s\n"),top3,strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 
@@ -274,7 +275,9 @@ int geramail(const char *dirname, int debug, const char *outdir, const char *ema
 			fputs(warea,stdout);
 	} else {
 		/* TRANSLATORS: The string is formatted using strftime. You can use
-		   any string formatting marker allowed by strftime. */
+		 * any string formatting marker allowed by strftime. The %c is the
+		 * time formatted according to the currently selected locale.
+		 */
 		strftime(Subject,sizeof(Subject),_("SARG report, %c"),local);
 		snprintf(warea,sizeof(warea),"%s -s \"%s\" \"%s\" <\"%s\"",MailUtility,Subject,email,top3);
 		if (debug)
