@@ -61,12 +61,14 @@ void htmlrel(void)
 	userscan uscan;
 
 	if (snprintf(tmp2,sizeof(tmp2),"%s/sargtmp.int_unsort",tmp)>=sizeof(tmp2)) {
-		debuga(_("File name too long: %s/sargtmp.int_unsort\n"),tmp);
+		debuga(_("Path too long: "));
+		debuga_more("%s/sargtmp.int_unsort\n",tmp);
 		exit(EXIT_FAILURE);
 	}
 
 	if (snprintf(tmp3,sizeof(tmp3),"%s/sargtmp.int_log",tmp)>=sizeof(tmp3)) {
-		debuga(_("File name too long: %s/sargtmp.int_log\n"),tmp);
+		debuga(_("Path too long: "));
+		debuga_more("%s/sargtmp.int_log\n",tmp);
 		exit(EXIT_FAILURE);
 	}
 
@@ -84,7 +86,8 @@ void htmlrel(void)
 	}
 	while ( (uinfo = userinfo_advancescan(uscan)) != NULL ) {
 		if (snprintf(warea,sizeof(warea),"%s/%s",outdirname,uinfo->filename)>=sizeof(warea)) {
-			debuga(_("Destination directory too long: %s/%s\n"),outdirname,uinfo->filename);
+			debuga(_("Destination directory too long: "));
+			debuga_more("%s/%s\n",outdirname,uinfo->filename);
 			exit(EXIT_FAILURE);
 		}
 		if (!uinfo->topuser) {
@@ -95,28 +98,31 @@ void htmlrel(void)
 
 		if (access(warea, R_OK) != 0) {
 			if (mkdir(warea,0755)) {
-				debuga(_("Cannot create directory %s - %s\n"),warea,strerror(errno));
+				debuga(_("Cannot create directory \"%s\": %s\n"),warea,strerror(errno));
 				exit(EXIT_FAILURE);
 			}
 		}
 		tmpsort(uinfo);
 
 		if (snprintf(arqin,sizeof(arqin),"%s/htmlrel.txt",tmp)>=sizeof(arqin)) {
-			debuga(_("Input file name too long: %s/htmlrel.txt\n"),tmp);
+			debuga(_("Path too long: "));
+			debuga_more("%s/htmlrel.txt\n",tmp);
 			exit(EXIT_FAILURE);
 		}
 		if ((fp_in = fopen(arqin, "r")) == 0){
 			if (uinfo->no_report) continue;
-			debuga(_("(html3) Cannot open file %s\n"),arqin);
+			debugapos("html3",_("Cannot open file \"%s\": %s\n"),arqin,strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 
 		if (snprintf(arqou,sizeof(arqou),"%s/%s/%s.html",outdirname,uinfo->filename,uinfo->filename)>=sizeof(arqou)) {
-			debuga(_("Output file name too long: %s/%s/%s.html\n"),outdirname,uinfo->filename,uinfo->filename);
+			debuga(_("Path too long: "));
+			debuga_more("%s/%s/%s.html\n",outdirname,uinfo->filename,uinfo->filename);
 			exit(EXIT_FAILURE);
 		}
 		if (snprintf(duser,sizeof(duser),"%s/denied_%s.html",outdirname,uinfo->filename)>=sizeof(duser)) {
-			debuga(_("File name too long: %s/denied_%s.html\n"),outdirname,uinfo->filename);
+			debuga(_("Path too long: "));
+			debuga_more("%s/denied_%s.html\n",outdirname,uinfo->filename);
 			exit(EXIT_FAILURE);
 		}
 		if(access(duser, R_OK) != 0)
@@ -125,7 +131,7 @@ void htmlrel(void)
 			have_denied_report=true;
 
 		if ((line=longline_create())==NULL) {
-			debuga(_("Not enough memory to read file %s\n"),arqin);
+			debuga(_("Not enough memory to read file \"%s\"\n"),arqin);
 			exit(EXIT_FAILURE);
 		}
 
@@ -137,35 +143,35 @@ void htmlrel(void)
 		while((buf=longline_read(fp_in,line))!=NULL) {
 			getword_start(&gwarea,buf);
 			if (getword_atoll(&ltemp,&gwarea,'\t')<0) {
-				debuga(_("There is a broken number of access in file %s\n"),arqin);
+				debuga(_("Invalid number of accesses in file \"%s\"\n"),arqin);
 				exit(EXIT_FAILURE);
 			}
 			tnacc+=ltemp;
 			if (getword_atoll(&ltemp,&gwarea,'\t')<0) {
-				debuga(_("There is a broken downloaded size in file %s\n"),arqin);
+				debuga(_("Invalid download size in file \"%s\"\n"),arqin);
 				exit(EXIT_FAILURE);
 			}
 			tnbytes+=ltemp;
 			if (getword_ptr(NULL,NULL,&gwarea,'\t')<0) {
-				debuga(_("There is a broken url in file %s\n"),arqin);
+				debuga(_("Invalid url in file \"%s\"\n"),arqin);
 				exit(EXIT_FAILURE);
 			}
 			if (getword_skip(MAXLEN,&gwarea,'\t')<0) {
-				debuga(_("There is a broken access code in file %s\n"),arqin);
+				debuga(_("Invalid access code in file \"%s\"\n"),arqin);
 				exit(EXIT_FAILURE);
 			}
 			if (getword_atoll(&ltemp,&gwarea,'\t')<0) {
-				debuga(_("There is a broken elapsed time in file %s\n"),arqin);
+				debuga(_("Invalid elapsed time in file \"%s\"\n"),arqin);
 				exit(EXIT_FAILURE);
 			}
 			tnelap+=ltemp;
 			if (getword_atoll(&ltemp,&gwarea,'\t')<0) {
-				debuga(_("There is a broken in-cache volume in file %s\n"),arqin);
+				debuga(_("Invalid in-cache volume in file \"%s\"\n"),arqin);
 				exit(EXIT_FAILURE);
 			}
 			tnincache+=ltemp;
 			if (getword_atoll(&ltemp,&gwarea,'\n')<0) {
-				debuga(_("There is a broken out-cache volume in file %s\n"),arqin);
+				debuga(_("Invalid out-of-cache volume in file \"%s\"\n"),arqin);
 				exit(EXIT_FAILURE);
 			}
 			tnoucache+=ltemp;
@@ -174,7 +180,7 @@ void htmlrel(void)
 		rewind(fp_in);
 
 		if ((fp_ou = fopen(arqou, "w")) == 0){
-			debuga(_("(html5) Cannot open file %s\n"),arqou);
+			debugapos("html5",_("Cannot open file \"%s\": %s\n"),arqou,strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 
@@ -219,7 +225,7 @@ void htmlrel(void)
 		fputs("</tr></thead>\n",fp_ou);
 
 		if(debug) {
-			debuga(_("Making report: %s\n"),uinfo->id);
+			debuga(_("Making report %s\n"),uinfo->id);
 		}
 		count=0;
 		arqip[0]='\0';
@@ -227,31 +233,31 @@ void htmlrel(void)
 		while((buf=longline_read(fp_in,line))!=NULL) {
 			getword_start(&gwarea,buf);
 			if (getword_atoll(&twork,&gwarea,'\t')<0) {
-				debuga(_("There is a broken number of access in file %s\n"),arqin);
+				debuga(_("Invalid number of accesses in file \"%s\"\n"),arqin);
 				exit(EXIT_FAILURE);
 			}
 			if (getword_atoll(&nnbytes,&gwarea,'\t')<0) {
-				debuga(_("There is a broken number of bytes in file %s\n"),arqin);
+				debuga(_("Invalid number of bytes in file \"%s\"\n"),arqin);
 				exit(EXIT_FAILURE);
 			}
 			if (getword_ptr(buf,&url,&gwarea,'\t')<0) {
-				debuga(_("There is a broken url in file %s\n"),arqin);
+				debuga(_("Invalid url in file \"%s\"\n"),arqin);
 				exit(EXIT_FAILURE);
 			}
 			if (getword(tmsg,sizeof(tmsg),&gwarea,'\t')<0) {
-				debuga(_("There is a broken access code in file %s\n"),arqin);
+				debuga(_("Invalid access code in file \"%s\"\n"),arqin);
 				exit(EXIT_FAILURE);
 			}
 			if (getword_atoll(&nnelap,&gwarea,'\t')<0) {
-				debuga(_("There is a broken elapsed time in file %s\n"),arqin);
+				debuga(_("Invalid elapsed time in file \"%s\"\n"),arqin);
 				exit(EXIT_FAILURE);
 			}
 			if (getword_atoll(&incache,&gwarea,'\t')<0) {
-				debuga(_("There is a broken in cache column in file %s\n"),arqin);
+				debuga(_("Invalid in-cache column in file \"%s\"\n"),arqin);
 				exit(EXIT_FAILURE);
 			}
 			if (getword_atoll(&oucache,&gwarea,'\n')<0) {
-				debuga(_("There is a broken out of cache column in file %s (%d)\n"),arqin,__LINE__);
+				debuga(_("Invalid out-of-cache column in file \"%s\"\n"),arqin);
 				exit(EXIT_FAILURE);
 			}
 
@@ -332,49 +338,50 @@ void htmlrel(void)
 
 			if(iprel) {
 				if (snprintf(arqip,sizeof(arqip),"%s/%s.ip",tmp,uinfo->filename)>=sizeof(arqip)) {
-					debuga(_("File name too long: %s/%s.ip\n"),tmp,uinfo->filename);
+					debuga(_("Path too long: "));
+					debuga_more("%s/%s.ip\n",tmp,uinfo->filename);
 					exit(EXIT_FAILURE);
 				}
 
 				if ((fp_ip = fopen(arqip, "r")) == 0){
-					debuga(_("(html6) Cannot open file %s\n"),arqip);
+					debugapos("html6",_("Cannot open file \"%s\": %s\n"),arqip,strerror(errno));
 					exit(EXIT_FAILURE);
 				}
 
 				if ((fp_ip2 = MY_FOPEN(tmp2, "a")) == 0){
-					debuga(_("(html7) Cannot open file %s\n"),tmp2);
+					debugapos("html7",_("Cannot open file \"%s\": %s\n"),tmp2,strerror(errno));
 					exit(EXIT_FAILURE);
 				}
 
 				if ((line1=longline_create())==NULL) {
-					debuga(_("Not enough memory to read file %s\n"),arqip);
+					debuga(_("Not enough memory to read file \"%s\"\n"),arqip);
 					exit(EXIT_FAILURE);
 				}
 				while((buf=longline_read(fp_ip,line1))!=NULL) {
 					getword_start(&gwarea,buf);
 					if (getword(user_ip,sizeof(user_ip),&gwarea,'\t')<0) {
-						debuga(_("Maybe you have a broken user IP in your %s file\n"),tmp3);
+						debuga(_("Invalid user IP in file \"%s\"\n"),tmp3);
 						exit(EXIT_FAILURE);
 					}
 					if (getword_ptr(buf,&user_url,&gwarea,'\t')<0) {
-						debuga(_("Maybe you have a broken url in your %s file\n"),tmp3);
+						debuga(_("Invalid url in file \"%s\"\n"),tmp3);
 						exit(EXIT_FAILURE);
 					}
 					if (strncmp(user_url,url,strlen(url))!=0) continue;
 					if (getword_skip(15,&gwarea,'\t')<0) {
-						debuga(_("Maybe you have a broken day in your %s file\n"),tmp3);
+						debuga(_("Invalid day in file \"%s\"\n"),tmp3);
 						exit(EXIT_FAILURE);
 					}
 					if (getword_skip(15,&gwarea,'\t')<0) {
-						debuga(_("Maybe you have a broken time in your %s file\n"),tmp3);
+						debuga(_("Invalid time in file \"%s\"\n"),tmp3);
 						exit(EXIT_FAILURE);
 					}
 					if (getword_atoll(&userbytes,&gwarea,'\t')<0) {
-						debuga(_("Maybe you have a broken size in your %s file\n"),tmp3);
+						debuga(_("Invalid size in file \"%s\"\n"),tmp3);
 						exit(EXIT_FAILURE);
 					}
 					if (getword_atoll(&userelap,&gwarea,'\0')<0) {
-						debuga(_("Maybe you have a broken elapsed time in your %s file\n"),tmp3);
+						debuga(_("Invalid elapsed time in file \"%s\"\n"),tmp3);
 						exit(EXIT_FAILURE);
 					}
 					fprintf(fp_ip2,"%s\t%"PRIu64"\t%"PRIu64"\n",user_ip,(uint64_t)userbytes,(uint64_t)userelap);
@@ -385,7 +392,8 @@ void htmlrel(void)
 				fclose(fp_ip2);
 
 				if (snprintf(csort,sizeof(csort),"sort -n -t \"\t\" -T \"%s\" -k 1,1 -k 2,2 -o \"%s\" \"%s\"",tmp,tmp3,tmp2)>=sizeof(csort)) {
-					debuga(_("Sort command too long when sorting file \"%s\" to \"%s\"\n"),tmp2,tmp3);
+					debuga(_("Command too long: "));
+					debuga_more("sort -n -t \"\t\" -T \"%s\" -k 1,1 -k 2,2 -o \"%s\" \"%s\"",tmp,tmp3,tmp2);
 					exit(EXIT_FAILURE);
 				}
 				cstatus=system(csort);
@@ -396,7 +404,7 @@ void htmlrel(void)
 				}
 
 				if ((fp_ip = MY_FOPEN(tmp3, "r")) == 0) {
-					debuga(_("(html8) Cannot open file %s\n"),tmp3);
+					debugapos("html8",_("Cannot open file \"%s\": %s\n"),tmp3,strerror(errno));
 					exit(EXIT_FAILURE);
 				}
 
@@ -408,21 +416,21 @@ void htmlrel(void)
 				olduserip[0]='\0';
 
 				if ((line1=longline_create())==NULL) {
-					debuga(_("Not enough memory to read file %s\n"),arqip);
+					debuga(_("Not enough memory to read file \"%s\"\n"),arqip);
 					exit(EXIT_FAILURE);
 				}
 				while((buf=longline_read(fp_ip,line1))!=NULL) {
 					getword_start(&gwarea,buf);
 					if (getword(user_ip,sizeof(user_ip),&gwarea,'\t')<0) {
-						debuga(_("Maybe you have a broken user IP in your %s file\n"),tmp3);
+						debuga(_("Invalid user IP in file \"%s\"\n"),tmp3);
 						exit(EXIT_FAILURE);
 					}
 					if (getword_atoll(&userbytes,&gwarea,'\t')<0) {
-						debuga(_("Maybe you have a broken size in your %s file\n"),tmp3);
+						debuga(_("Invalid size in file \"%s\"\n"),tmp3);
 						exit(EXIT_FAILURE);
 					}
 					if (getword_atoll(&userelap,&gwarea,'\0')<0) {
-						debuga(_("Maybe you have a broken elapsed time in your %s file\n"),tmp3);
+						debuga(_("Invalid elapsed time in file \"%s\"\n"),tmp3);
 						exit(EXIT_FAILURE);
 					}
 					if(strcmp(user_ip,olduserip) != 0) {
@@ -530,7 +538,7 @@ void htmlrel(void)
 				limit_flag=0;
 				if(access(PerUserLimitFile, R_OK) == 0) {
 					if((fp_usr = fopen(PerUserLimitFile, "r")) == 0) {
-						debuga(_("(html9) Cannot open file %s\n"),PerUserLimitFile);
+						debugapos("html9",_("Cannot open file \"%s\": %s\n"),PerUserLimitFile,strerror(errno));
 						exit(EXIT_FAILURE);
 					}
 					while(fgets(tmp6,sizeof(tmp6),fp_usr)!=NULL) {
@@ -545,14 +553,14 @@ void htmlrel(void)
 
 				if(!limit_flag) {
 					if((fp_usr = fopen(PerUserLimitFile, "a")) == 0) {
-						debuga(_("(html10) Cannot open file %s\n"),PerUserLimitFile);
+						debugapos("html10",_("Cannot open file \"%s\": %s\n"),PerUserLimitFile,strerror(errno));
 						exit(EXIT_FAILURE);
 					}
 					fprintf(fp_usr,"%s\n",uinfo->ip);
 					fclose(fp_usr);
 
 					if(debug)
-						debuga(_("User %s limit exceeded (%d MB). Added to file %s\n"),uinfo->label,PerUserLimit,PerUserLimitFile);
+						debuga(_("User %s limit exceeded (%d MB). Added to file \"%s\"\n"),uinfo->label,PerUserLimit,PerUserLimitFile);
 				}
 			}
 		}
@@ -583,9 +591,9 @@ void htmlrel(void)
 
 		fputs("</table></div>\n",fp_ou);
 		if (write_html_trailer(fp_ou)<0)
-			debuga(_("Write error in file %s\n"),arqou);
+			debuga(_("Write error in file \"%s\"\n"),arqou);
 		if (fclose(fp_ou)==EOF)
-			debuga(_("Failed to close file %s - %s\n"),arqou,strerror(errno));
+			debuga(_("Failed to close file \"%s\": %s\n"),arqou,strerror(errno));
 
 		htaccess(uinfo);
 	}
