@@ -55,7 +55,7 @@ void make_index(void)
 
 	// convert any old report hierarchy
 	if ((dirp = opendir(outdir)) == NULL) {
-		debuga(_("Failed to open directory %s - %s\n"),outdir,strerror(errno));
+		debuga(_("Failed to open directory \"%s\": %s\n"),outdir,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	while ((direntp = readdir( dirp )) != NULL) {
@@ -109,7 +109,7 @@ static void make_date_index(void)
 
 	nyears=0;
 	if ((dirp = opendir(outdir)) == NULL) {
-		debuga(_("Failed to open directory %s - %s\n"),outdir,strerror(errno));
+		debuga(_("Failed to open directory \"%s\": %s\n"),outdir,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	while ((direntp = readdir( dirp )) != NULL) {
@@ -140,7 +140,7 @@ static void make_date_index(void)
 	order=(strcmp(IndexSortOrder,"A") == 0) ? 1 : -1;
 
 	if((fp_ou=fopen(yearindex,"w"))==NULL) {
-		debuga(_("(index) Cannot open file %s - %s\n"),yearindex,strerror(errno));
+		debugapos("index",_("Cannot open file \"%s\": %s\n"),yearindex,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	write_html_header(fp_ou,0,ngettext("SARG report","SARG reports",nyears),HTML_JS_NONE);
@@ -164,7 +164,7 @@ static void make_date_index(void)
 		// Year dir
 		nmonths=0;
 		if ((dirp2 = opendir(yeardir)) == NULL) {
-			debuga(_("Failed to open directory %s - %s\n"),yeardir,strerror(errno));
+			debuga(_("Failed to open directory \"%s\": %s\n"),yeardir,strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 		while ((direntp2 = readdir( dirp2 )) != NULL) {
@@ -192,7 +192,7 @@ static void make_date_index(void)
 		closedir(dirp2);
 		sprintf(monthindex,"%s/index.html",yeardir);
 		if((fp_ou2=fopen(monthindex,"w"))==NULL) {
-			debuga(_("(index) Cannot open file %s - %s\n"),monthindex,strerror(errno));
+			debugapos("index",_("Cannot open file \"%s\": %s\n"),monthindex,strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 		snprintf(title,sizeof(title),ngettext("SARG: report for %04d","SARG: reports for %04d",nmonths),year);
@@ -225,7 +225,7 @@ static void make_date_index(void)
 			// month dir
 			ndays=0;
 			if ((dirp3 = opendir(monthdir)) == NULL) {
-				debuga(_("Failed to open directory %s - %s\n"),monthdir,strerror(errno));
+				debuga(_("Cannot open directory \"%s\": %s\n"),monthdir,strerror(errno));
 				exit(EXIT_FAILURE);
 			}
 			while ((direntp3 = readdir( dirp3 )) != NULL) {
@@ -253,7 +253,7 @@ static void make_date_index(void)
 			closedir(dirp3);
 			sprintf(dayindex,"%s/index.html",monthdir);
 			if((fp_ou3=fopen(dayindex,"w"))==NULL) {
-				debuga(_("(index) Cannot open file %s - %s\n"),dayindex,strerror(errno));
+				debugapos("index",_("Cannot open file \"%s\": %s\n"),dayindex,strerror(errno));
 				exit(EXIT_FAILURE);
 			}
 			snprintf(title,sizeof(title),ngettext("SARG: report for %04d/%02d","SARG: reports for %04d/%02d",ndays),year,month);
@@ -279,20 +279,20 @@ static void make_date_index(void)
 			if (write_html_trailer(fp_ou3)<0)
 				debuga(_("Write error in the index %s\n"),dayindex);
 			if (fclose(fp_ou3)==EOF)
-				debuga(_("Failed to close the index file %s - %s\n"),dayindex,strerror(errno));
+				debuga(_("Failed to close file \"%s\": %s\n"),dayindex,strerror(errno));
 		}
 		fputs("</table></div>\n",fp_ou2);
 		if (write_html_trailer(fp_ou2)<0)
 			debuga(_("Write error in the index %s\n"),monthindex);
 		if (fclose(fp_ou2)==EOF)
-			debuga(_("Failed to close the index file %s - %s\n"),monthindex,strerror(errno));
+			debuga(_("Failed to close file \"%s\": %s\n"),monthindex,strerror(errno));
 	}
 
 	fputs("</table></div>\n",fp_ou);
 	if (write_html_trailer(fp_ou)<0)
 		debuga(_("Write error in the index %s\n"),yearindex);
 	if (fclose(fp_ou)==EOF)
-		debuga(_("Failed to close the index file %s - %s\n"),yearindex,strerror(errno));
+		debuga(_("Failed to close file \"%s\": %s\n"),yearindex,strerror(errno));
 }
 
 static void make_file_index(void)
@@ -327,7 +327,7 @@ static void make_file_index(void)
 	order=(strcmp(IndexSortOrder,"A") == 0) ? 1 : -1;
 
 	if ((dirp = opendir(outdir)) == NULL) {
-		debuga(_("Failed to open directory %s - %s\n"),outdir,strerror(errno));
+		debuga(_("Cannot open directory \"%s\": %s\n"),outdir,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -364,32 +364,32 @@ static void make_file_index(void)
 			*/
 			getword_start(&gwarea,data);
 			if (getword_skip(16,&gwarea,' ')<0) {
-				debuga(_("Maybe you have a broken week day in your %s%s/sarg-date file\n"),outdir,direntp->d_name);
+				debuga(_("Invalid week day in file \"%s%s/sarg-date\"\n"),outdir,direntp->d_name);
 				exit(EXIT_FAILURE);
 			}
 			if (getword_multisep(mon,sizeof(mon),&gwarea,' ')<0) {
-				debuga(_("Maybe you have a broken month in your %s%s/sarg-date file\n"),outdir,direntp->d_name);
+				debuga(_("Invalid month in file \"%s%s/sarg-date\"\n"),outdir,direntp->d_name);
 				exit(EXIT_FAILURE);
 			}
 			if (getword_multisep(day,sizeof(day),&gwarea,' ')<0) {
-				debuga(_("Maybe you have a broken day in your %s%s/sarg-date file\n"),outdir,direntp->d_name);
+				debuga(_("Invalid day in file \"%s%s/sarg-date\"\n"),outdir,direntp->d_name);
 				exit(EXIT_FAILURE);
 			}
 			if (getword_multisep(hour,sizeof(hour),&gwarea,' ')<0) {
-				debuga(_("Maybe you have a broken time in your %s%s/sarg-date file\n"),outdir,direntp->d_name);
+				debuga(_("Invalid time in file \"%s%s/sarg-date\"\n"),outdir,direntp->d_name);
 				exit(EXIT_FAILURE);
 			}
 			do {
 				if (getword_multisep(year,sizeof(year),&gwarea,' ')<0) {
-					debuga(_("Maybe you have a broken year in your %s%s/sarg-date file\n"),outdir,direntp->d_name);
+					debuga(_("Invalid year in file \"%s%s/sarg-date\"\n"),outdir,direntp->d_name);
 					exit(EXIT_FAILURE);
 				}
 			} while (year[0] && !isdigit(year[0])); //skip time zone information with spaces until the year is found
 			if (sscanf(hour,"%d:%d:%d",&ihour,&iminute,&isecond)!=3) {
-				debuga(_("Maybe you have a broken time in your %s%s/sarg-date file\n"),outdir,direntp->d_name);
+				debuga(_("Invalid time in file \"%s%s/sarg-date\"\n"),outdir,direntp->d_name);
 				exit(EXIT_FAILURE);
 			}
-			buildymd(day,mon,year,ftime);
+			buildymd(day,mon,year,ftime,sizeof(ftime));
 			snprintf(item->creationdate,sizeof(item->creationdate),"%s%02d%02d%02d",ftime, ihour, iminute, isecond);
 		}
 		item->dirname=strdup(direntp->d_name);
@@ -421,7 +421,7 @@ static void make_file_index(void)
 	closedir( dirp );
 
 	if((fp_ou=fopen(wdir,"w"))==NULL) {
-		debuga(_("(index) Cannot open file %s\n"),wdir);
+		debugapos("index",_("Cannot open file \"%s\": %s\n"),wdir,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	write_html_header(fp_ou,0,ngettext("SARG report","SARG reports",nsort),HTML_JS_SORTTABLE);
@@ -455,7 +455,7 @@ static void make_file_index(void)
 	if (write_html_trailer(fp_ou)<0)
 		debuga(_("Write error in the index %s\n"),wdir);
 	if (fclose(fp_ou)==EOF)
-		debuga(_("Failed to close the index file %s - %s\n"),wdir,strerror(errno));
+		debuga(_("Failed to close file \"%s\": %s\n"),wdir,strerror(errno));
 
 	if (sortlist) {
 		for (i=0 ; i<nsort ; i++) {
@@ -540,7 +540,7 @@ static void file_index_to_date_index(const char *entry)
 	ndirlen=sprintf(newdir,"%s%04d",outdir,y1);
 	if (access(newdir, R_OK) != 0) {
 		if (mkdir(newdir,0755)) {
-			debuga(_("Cannot create directory %s - %s\n"),newdir,strerror(errno));
+			debuga(_("Cannot create directory \"%s\": %s\n"),newdir,strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 	}
@@ -548,7 +548,7 @@ static void file_index_to_date_index(const char *entry)
 	else ndirlen+=sprintf(newdir+ndirlen,"/%02d",m1);
 	if (access(newdir, R_OK) != 0) {
 		if (mkdir(newdir,0755)) {
-			debuga(_("Cannot create directory %s - %s\n"),newdir,strerror(errno));
+			debuga(_("Cannot create directory \"%s\": %s\n"),newdir,strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 	}
@@ -558,7 +558,7 @@ static void file_index_to_date_index(const char *entry)
 
 	sprintf(olddir,"%s%s",outdir,entry);
 	if (rename(olddir,newdir)) {
-		debuga(_("(index) rename error from \"%s\" to \"%s\" - %s\n"),olddir,newdir,strerror(errno));
+		debugapos("index",_("Failed to rename \"%s\" into \"%s\": %s\n"),olddir,newdir,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -569,7 +569,7 @@ static void file_index_to_date_index(const char *entry)
 
 		sprintf(linkdir,"%simages",outdir);
 		if (symlink(linkdir,newdir)) {
-			debuga(_("failed to create link \"%s\" to \"%s\" - %s\n"),linkdir,newdir,strerror(errno));
+			debuga(_("Failed to create link \"%s\" to \"%s\": %s\n"),linkdir,newdir,strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 #else
@@ -660,7 +660,7 @@ static void date_index_to_file_index(const char *entry)
 			else continue;
 			sprintf(olddir,"%s%04d/%s/%s",outdir,y1,direntp2->d_name,direntp3->d_name);
 			if(rename(olddir,newdir)) {
-				debuga(_("(index) rename error from \"%s\" to \"%s\" - %s\n"),olddir,newdir,strerror(errno));
+				debugapos("index",_("Failed to rename \"%s\" into \"%s\": %s\n"),olddir,newdir,strerror(errno));
 				exit(EXIT_FAILURE);
 			}
 		}
