@@ -276,7 +276,7 @@ void name2ip(char *name,int name_size)
 	error=getaddrinfo(addr,NULL,NULL,&res);
 	if (error) {
 		freeaddrinfo(res);
-		debuga(_("Cannot resolve host name %s: %s\n"),name,gai_strerror(error));
+		debuga(_("Cannot resolve host name \"%s\": %s\n"),name,gai_strerror(error));
 		exit(EXIT_FAILURE);
 	}
 	if (res->ai_family==AF_INET) {
@@ -320,7 +320,7 @@ void name2ip(char *name,int name_size)
 	getword_start(&gwarea,inet_ntoa(ia));
 	if (getword(n4,sizeof(n4),&gwarea,'.')<0 || getword(n3,sizeof(n3),&gwarea,'.')<0 ||
 	    getword(n2,sizeof(n2),&gwarea,'.')<0 || getword(n1,sizeof(n1),&gwarea,0)<0) {
-		printf("SARG: Maybe you have a broken record or garbage in your %s ip address.\n",gwarea.beginning);
+		debuga(_("Invalid record in IP address \"%s\"\n"),gwarea.beginning);
 		exit(EXIT_FAILURE);
 	}
 	snprintf(name,name_size,"%s.%s.%s.%s",n1,n2,n3,n4);
