@@ -46,6 +46,9 @@ struct userfilestruct
 numlist weekdays = { { 0, 1, 2, 3, 4, 5, 6 }, 7 };
 numlist hours = { { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23 }, 24 };
 
+//! Selected locale set through the environment variable.
+char *CurrentLocale=NULL;
+
 static void getusers(const char *pwdfile, int debug);
 
 int main(int argc,char *argv[])
@@ -190,7 +193,8 @@ int main(int argc,char *argv[])
 #endif
 
 #if defined(ENABLE_NLS) && defined(HAVE_LOCALE_H)
-	if (!setlocale (LC_ALL, "")) {
+	CurrentLocale=setlocale (LC_ALL, "");
+	if (!CurrentLocale) {
 		fprintf(stderr,"SARG: Cannot set the locale LC_ALL to the environment variable\n");
 		exit(EXIT_FAILURE);
 	}
@@ -422,11 +426,11 @@ int main(int argc,char *argv[])
 				break;
 			case 'l':
 				if (NAccessLog>=MAXLOGS) {
-					debuga(_("Too many log files passed on command line with option -l.\n"));
+					debuga(_("Too many log files passed on command line with option %s.\n"),"-l");
 					exit(EXIT_FAILURE);
 				}
 				if (strlen(optarg)>=MAX_LOG_FILELEN) {
-					debuga(_("Log file name too long passed on command line with option -l: %s\n"),optarg);
+					debuga(_("Log file name too long passed on command line with option %s: %s\n"),"-l",optarg);
 					exit(EXIT_FAILURE);
 				}
 				strcpy(AccessLog[NAccessLog],optarg);
@@ -435,11 +439,11 @@ int main(int argc,char *argv[])
 				break;
 			case 'L':
 				if (NRedirectorLogs>MAX_REDIRECTOR_LOGS) {
-					debuga(_("Too many redirector logs passed on command line with option -L.\n"));
+					debuga(_("Too many log files passed on command line with option %s.\n"),"-L");
 					exit(EXIT_FAILURE);
 				}
 				if (strlen(optarg)>=MAX_REDIRECTOR_FILELEN) {
-					debuga(_("Redirector log file name too long passed on command line with opton -L: %s\n"),optarg);
+					debuga(_("Log file name too long passed on command line with opton %s: %s\n"),"-L",optarg);
 					exit(EXIT_FAILURE);
 				}
 				strcpy(RedirectorLogs[NRedirectorLogs],optarg);
@@ -544,7 +548,7 @@ int main(int argc,char *argv[])
 
 	if(ConfigFile[0] == '\0') snprintf(ConfigFile,sizeof(ConfigFile),"%s/sarg.conf",SYSCONFDIR);
 	if(access(ConfigFile, R_OK) != 0) {
-		debuga(_("Cannot open config file: %s - %s\n"),ConfigFile,strerror(errno));
+		debuga(_("Cannot open file \"%s\": %s\n"),ConfigFile,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -736,11 +740,11 @@ int main(int argc,char *argv[])
 		printf(_("                  Debug messages (-x) = %s\n"),(debug) ? _("Yes") : _("No"));
 		printf(_("                Process messages (-z) = %s\n"),(debugz) ? _("Yes") : _("No"));
 		printf(_(" Previous reports to keep (--lastlog) = %d\n"),LastLog);
-		printf(_("sarg version: %s\n"),VERSION);
+		printf(_("SARG version: %s\n"),VERSION);
 	}
 
 	if(debug)
-		debuga(_("sarg version: %s\n"),VERSION);
+		debuga(_("SARG version: %s\n"),VERSION);
 
 #ifdef ENABLE_DOUBLE_CHECK_DATA
 	debuga(_("Sarg compiled to report warnings if the output is inconsistent\n"));
@@ -773,7 +777,7 @@ int main(int argc,char *argv[])
 #warning "No rlimit resource for the number of open files"
 #endif
 		if(rc == -1) {
-			debuga(_("setrlimit error - %s\n"),strerror(errno));
+			debuga(_("setrlimit error: %s\n"),strerror(errno));
 		}
 
 		if(debug)
@@ -793,14 +797,14 @@ int main(int argc,char *argv[])
 	if(DataFile[0]=='\0') {
 		if((ReportType & REPORT_TYPE_DENIED) != 0) {
 			if((fp_denied=MY_FOPEN(denied_unsort,"w"))==NULL) {
-				debuga(_("(log) Cannot open file: %s - %s\n"),denied_unsort,strerror(errno));
+				debugapos("log",_("Cannot open file \"%s\": %s\n"),denied_unsort,strerror(errno));
 				exit(EXIT_FAILURE);
 			}
 		}
 
 		if((ReportType & REPORT_TYPE_DENIED) != 0 || (ReportType & REPORT_TYPE_AUTH_FAILURES) != 0) {
 			if((fp_authfail=MY_FOPEN(authfail_unsort,"w"))==NULL) {
-				debuga(_("(log) Cannot open file: %s - %s\n"),authfail_unsort,strerror(errno));
+				debugapos("log",_("Cannot open file \"%s\": %s\n"),authfail_unsort,strerror(errno));
 				exit(EXIT_FAILURE);
 			}
 		}
@@ -820,7 +824,7 @@ int main(int argc,char *argv[])
 		} else {
 			if (date[0]!='\0') {
 				if (stat(arq,&logstat)!=0) {
-					debuga(_("Cannot get the modification time of input log file %s (%s). Processing it anyway\n"),arq,strerror(errno));
+					debuga(_("Cannot get the modification time of input log file \"%s\": %s\nProcessing it anyway\n"),arq,strerror(errno));
 				} else {
 					struct tm *logtime=localtime(&logstat.st_mtime);
 					if ((logtime->tm_year+1900)*10000+(logtime->tm_mon+1)*100+logtime->tm_mday<dfrom) {
@@ -831,7 +835,7 @@ int main(int argc,char *argv[])
 			}
 			fp_in=decomp(arq,&from_pipe);
 			if(fp_in==NULL) {
-				debuga(_("(log) Cannot open log file: %s - %s\n"),arq,strerror(errno));
+				debugapos("log",_("Cannot open file \"%s\": %s\n"),arq,strerror(errno));
 				exit(EXIT_FAILURE);
 			}
 			if(debug) debuga(_("Reading access log file: %s\n"),arq);
@@ -862,7 +866,7 @@ int main(int argc,char *argv[])
 					}
 			}
 			rewind(fp_in);
-			printf(_("SARG: Records in file: %lu, reading: %3.2f%%"),recs1,(float) 0);
+			printf(_("SARG: Records in file: %lu, reading: %3.2lf%%"),recs1,0.);
 			putchar('\r');
 			fflush( stdout ) ;
 		}
@@ -899,11 +903,12 @@ int main(int argc,char *argv[])
 					my_mkdir(ParsedOutputLog);
 				}
 				if (snprintf(arq_log,sizeof(arq_log),"%s/sarg_temp.log",ParsedOutputLog)>=sizeof(arq_log)) {
-					debuga(_("File name too long: %s/sarg_temp.log\n"),ParsedOutputLog);
+					debuga(_("Path too long: "));
+					debuga_more("%s/sarg_temp.log\n",ParsedOutputLog);
 					exit(EXIT_FAILURE);
 				}
 				if((fp_log=MY_FOPEN(arq_log,"w"))==NULL) {
-					debuga(_("(log) Cannot open log file: %s - %s\n"),arq_log,strerror(errno));
+					debugapos("log",_("Cannot open file \"%s\": %s\n"),arq_log,strerror(errno));
 					exit(EXIT_FAILURE);
 				}
 				fputs("*** SARG Log ***\n",fp_log);
@@ -928,7 +933,7 @@ int main(int argc,char *argv[])
 				getword_start(&gwarea,ExcludeString);
 				while(strchr(gwarea.current,':') != 0) {
 					if (getword_multisep(val1,sizeof(val1),&gwarea,':')<0) {
-						debuga(_("Maybe you have a broken record or garbage in your exclusion string\n"));
+						debuga(_("Invalid record in exclusion string\n"));
 						exit(EXIT_FAILURE);
 					}
 					if((str=(char *) strstr(linebuf,val1)) != (char *) NULL ) {
@@ -949,7 +954,7 @@ int main(int argc,char *argv[])
 			if (ilf==ILF_Squid || ilf==ILF_Common || ilf==ILF_Unknown) {
 				getword_start(&gwarea,linebuf);
 				if (getword(data,sizeof(data),&gwarea,' ')<0) {
-					debuga(_("Maybe you have a broken time in your access.log file\n"));
+					debuga(_("Invalid time in file \"%s\"\n"),arq);
 					exit(EXIT_FAILURE);
 				}
 				if((str=(char *) strchr(data, '.')) != (char *) NULL && (str=(char *) strchr(str+1, '.')) != (char *) NULL ) {
@@ -957,44 +962,44 @@ int main(int argc,char *argv[])
 					strcpy(elap,"0");
 					if(squid24) {
 						if (getword(user,sizeof(user),&gwarea,' ')<0 || getword_skip(255,&gwarea,' ')<0) {
-							debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+							debuga(_("Invalid record in file \"%s\"\n"),arq);
 							exit(EXIT_FAILURE);
 						}
 					} else {
 						if (getword_skip(255,&gwarea,' ')<0 || getword(user,sizeof(user),&gwarea,' ')<0) {
-							debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+							debuga(_("Invalid record in file \"%s\"\n"),arq);
 							exit(EXIT_FAILURE);
 						}
 					}
 					if (getword(data,sizeof(data),&gwarea,']')<0 || getword_skip(MAXLEN,&gwarea,'"')<0 ||
 					    getword(fun,sizeof(fun),&gwarea,' ')<0) {
-						debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+						debuga(_("Invalid record in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					if (getword_ptr(linebuf,&full_url,&gwarea,' ')<0) {
-						debuga(_("Maybe you have a broken url in your %s file\n"),arq);
+						debuga(_("Invalid url in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					if (getword_skip(MAXLEN,&gwarea,' ')<0) {
-						debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+						debuga(_("Invalid record in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					if (getword(code2,sizeof(code2),&gwarea,' ')<0) {
-						debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+						debuga(_("Invalid record in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					if (getword(tam,sizeof(tam),&gwarea,' ')<0) {
-						debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+						debuga(_("Invalid record in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					if((str=(char *) strchr(gwarea.current, ' ')) != (char *) NULL ) {
 						if (getword(code,sizeof(code),&gwarea,' ')<0) {
-							debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+							debuga(_("Invalid record in file \"%s\"\n"),arq);
 							exit(EXIT_FAILURE);
 						}
 					} else {
 						if (getword(code,sizeof(code),&gwarea,'\0')<0) {
-							debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+							debuga(_("Invalid record in file \"%s\"\n"),arq);
 							exit(EXIT_FAILURE);
 						}
 					}
@@ -1010,24 +1015,24 @@ int main(int argc,char *argv[])
 
 					getword_start(&gwarea,data+1);
 					if (getword_multisep(data,sizeof(data),&gwarea,':')<0){
-						debuga(_("Maybe you have a broken date in your %s file\n"),arq);
+						debuga(_("Invalid date in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					if (getword_multisep(hora,sizeof(hora),&gwarea,' ')<0){
-						debuga(_("Maybe you have a broken date in your %s file\n"),arq);
+						debuga(_("Invalid date in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					getword_start(&gwarea,data);
 					if (getword_atoll(&iday,&gwarea,'/')<0){
-						debuga(_("Maybe you have a broken date in your %s file\n"),arq);
+						debuga(_("Invalid date in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					if (getword(mes,sizeof(mes),&gwarea,'/')<0){
-						debuga(_("Maybe you have a broken date in your %s file\n"),arq);
+						debuga(_("Invalid date in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					if (getword_atoll(&iyear,&gwarea,'/')<0){
-						debuga(_("Maybe you have a broken date in your %s file\n"),arq);
+						debuga(_("Invalid date in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 
@@ -1036,7 +1041,7 @@ int main(int argc,char *argv[])
 					computedate(iyear,imonth,iday,&tt);
 					if (sscanf(hora,"%d:%d:%d",&tt.tm_hour,&tt.tm_min,&tt.tm_sec)!=3 || tt.tm_hour<0 || tt.tm_hour>=24 ||
 							tt.tm_min<0 || tt.tm_min>=60 || tt.tm_sec<0 || tt.tm_sec>=60) {
-						debuga(_("Invalid time found in %s\n"),arq);
+						debuga(_("Invalid time in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					t=&tt;
@@ -1044,37 +1049,37 @@ int main(int argc,char *argv[])
 
 				if(ilf==ILF_Unknown || ilf==ILF_Squid) {
 					if (getword(elap,sizeof(elap),&gwarea,' ')<0) {
-						debuga(_("Maybe you have a broken elapsed time in your %s file\n"),arq);
+						debuga(_("Invalid elapsed time in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					while(strcmp(elap,"") == 0 && gwarea.current[0] != '\0')
 						if (getword(elap,sizeof(elap),&gwarea,' ')<0) {
-							debuga(_("Maybe you have a broken elapsed time in your %s file\n"),arq);
+							debuga(_("Invalid elapsed time in file \"%s\"\n"),arq);
 							exit(EXIT_FAILURE);
 						}
 					if(strlen(elap) < 1) continue;
 					if (getword(ip,sizeof(ip),&gwarea,' ')<0){
-						debuga(_("Maybe you have a broken client IP address in your %s file\n"),arq);
+						debuga(_("Invalid client IP address in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					if (getword(code,sizeof(code),&gwarea,' ')<0){
-						debuga(_("Maybe you have a broken result code in your %s file\n"),arq);
+						debuga(_("Invalid result code in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					if (getword(tam,sizeof(tam),&gwarea,' ')<0){
-						debuga(_("Maybe you have a broken amount of data in your %s file\n"),arq);
+						debuga(_("Invalid amount of data in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					if (getword(fun,sizeof(fun),&gwarea,' ')<0){
-						debuga(_("Maybe you have a broken request method in your %s file\n"),arq);
+						debuga(_("Invalid request method in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					if (getword_ptr(linebuf,&full_url,&gwarea,' ')<0){
-						debuga(_("Maybe you have a broken url in your %s file\n"),arq);
+						debuga(_("Invalid url in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					if (getword(user,sizeof(user),&gwarea,' ')<0){
-						debuga(_("Maybe you have a broken user ID in your %s file\n"),arq);
+						debuga(_("Invalid user ID in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					ilf=ILF_Squid;
@@ -1095,59 +1100,59 @@ int main(int argc,char *argv[])
 			if (ilf==ILF_Sarg) {
 				getword_start(&gwarea,linebuf);
 				if (getword(data,sizeof(data),&gwarea,'\t')<0){
-					debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+					debuga(_("Invalid record in file \"%s\"\n"),arq);
 					exit(EXIT_FAILURE);
 				}
 				if (getword(hora,sizeof(hora),&gwarea,'\t')<0) {
-					debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+					debuga(_("Invalid record in file \"%s\"\n"),arq);
 					exit(EXIT_FAILURE);
 				}
 				if (getword(user,sizeof(user),&gwarea,'\t')<0) {
-					debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+					debuga(_("Invalid record in file \"%s\"\n"),arq);
 					exit(EXIT_FAILURE);
 				}
 				if (getword(ip,sizeof(ip),&gwarea,'\t')<0) {
-					debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+					debuga(_("Invalid record in file \"%s\"\n"),arq);
 					exit(EXIT_FAILURE);
 				}
 				if (getword_ptr(linebuf,&full_url,&gwarea,'\t')<0){
-					debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+					debuga(_("Invalid record in file \"%s\"\n"),arq);
 					exit(EXIT_FAILURE);
 				}
 				if (getword(tam,sizeof(tam),&gwarea,'\t')<0){
-					debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+					debuga(_("Invalid record in file \"%s\"\n"),arq);
 					exit(EXIT_FAILURE);
 				}
 				if (getword(code,sizeof(code),&gwarea,'\t')<0){
-					debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+					debuga(_("Invalid record in file \"%s\"\n"),arq);
 					exit(EXIT_FAILURE);
 				}
 				if (getword(elap,sizeof(elap),&gwarea,'\t')<0){
-					debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+					debuga(_("Invalid record in file \"%s\"\n"),arq);
 					exit(EXIT_FAILURE);
 				}
 				if (getword(smartfilter,sizeof(smartfilter),&gwarea,'\0')<0){
-					debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+					debuga(_("Invalid record in file \"%s\"\n"),arq);
 					exit(EXIT_FAILURE);
 				}
 				getword_start(&gwarea,data);
 				if (getword_atoll(&iday,&gwarea,'/')<0 || iday<1 || iday>31){
-					debuga(_("Maybe you have a broken date in your %s file\n"),arq);
+					debuga(_("Invalid record in file \"%s\"\n"),arq);
 					exit(EXIT_FAILURE);
 				}
 				if (getword_atoll(&imonth,&gwarea,'/')<0 || imonth<1 || imonth>12){
-					debuga(_("Maybe you have a broken date in your %s file\n"),arq);
+					debuga(_("Invalid record in file \"%s\"\n"),arq);
 					exit(EXIT_FAILURE);
 				}
 				if (getword_atoll(&iyear,&gwarea,'\0')<0){
-					debuga(_("Maybe you have a broken date in your %s file\n"),arq);
+					debuga(_("Invalid record in file \"%s\"\n"),arq);
 					exit(EXIT_FAILURE);
 				}
 				idata=builddia(iday,imonth,iyear);
 				computedate(iyear,imonth,iday,&tt);
 				if (sscanf(hora,"%d:%d:%d",&tt.tm_hour,&tt.tm_min,&tt.tm_sec)!=3 || tt.tm_hour<0 || tt.tm_hour>=24 ||
 						tt.tm_min<0 || tt.tm_min>=60 || tt.tm_sec<0 || tt.tm_sec>=60) {
-					debuga(_("Invalid time found in %s\n"),arq);
+					debuga(_("Invalid time in file \"%s\"\n"),arq);
 					exit(EXIT_FAILURE);
 				}
 				t=&tt;
@@ -1160,14 +1165,14 @@ int main(int argc,char *argv[])
 					getword_start(&gwarea,linebuf);
 					// remove the #Fields: column at the beginning of the line
 					if (getword_skip(1000,&gwarea,' ')<0){
-						debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+						debuga(_("Invalid record in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					for (ncols=0 ; ncols<ISACOL_Last ; ncols++) cols[ncols]=-1;
 					ncols=0;
 					while(gwarea.current[0] != '\0') {
 						if (getword(val1,sizeof(val1),&gwarea,'\t')<0){
-							debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+							debuga(_("Invalid record in file \"%s\"\n"),arq);
 							exit(EXIT_FAILURE);
 						}
 						if(strcmp(val1,"c-ip") == 0) cols[ISACOL_Ip]=ncols;
@@ -1191,42 +1196,42 @@ int main(int argc,char *argv[])
 				getword_start(&gwarea,linebuf);
 				for (x=0 ; x<isa_ncols ; x++) {
 					if (getword_ptr(linebuf,&str,&gwarea,'\t')<0) {
-						debuga(_("Maybe you have a broken record or garbage in your %s file\n"),arq);
+						debuga(_("Invalid record in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 					if (x==isa_cols[ISACOL_Ip]) {
 						if (strlen(str)>=sizeof(ip)) {
-							debuga(_("Maybe you have a broken IP in your %s file\n"),arq);
+							debuga(_("Invalid IP address in file \"%s\"\n"),arq);
 							exit(EXIT_FAILURE);
 						}
 						strcpy(ip,str);
 					} else if (x==isa_cols[ISACOL_UserName]) {
 						if (strlen(str)>=sizeof(user)) {
-							debuga(_("Maybe you have a broken user ID in your %s file\n"),arq);
+							debuga(_("Invalid user ID in file \"%s\"\n"),arq);
 							exit(EXIT_FAILURE);
 						}
 						strcpy(user,str);
 					} else if (x==isa_cols[ISACOL_Date]) {
 						if (strlen(str)>=sizeof(data)) {
-							debuga(_("Maybe you have a broken date in your %s file\n"),arq);
+							debuga(_("Invalid record in file \"%s\"\n"),arq);
 							exit(EXIT_FAILURE);
 						}
 						strcpy(data,str);
 					} else if (x==isa_cols[ISACOL_Time]) {
 						if (strlen(str)>=sizeof(hora)) {
-							debuga(_("Maybe you have a broken time in your %s file\n"),arq);
+							debuga(_("Invalid time in file \"%s\"\n"),arq);
 							exit(EXIT_FAILURE);
 						}
 						strcpy(hora,str);
 					} else if (x==isa_cols[ISACOL_TimeTaken]) {
 						if (strlen(str)>=sizeof(elap)) {
-							debuga(_("Maybe you have a broken download duration in your %s file\n"),arq);
+							debuga(_("Invalid download duration in file \"%s\"\n"),arq);
 							exit(EXIT_FAILURE);
 						}
 						strcpy(elap,str);
 					} else if (x==isa_cols[ISACOL_Bytes]) {
 						if (strlen(str)>=sizeof(tam)) {
-							debuga(_("Maybe you have a broken download size in your %s file\n"),arq);
+							debuga(_("Invalid download size in file \"%s\"\n"),arq);
 							exit(EXIT_FAILURE);
 						}
 						strcpy(tam,str);
@@ -1234,7 +1239,7 @@ int main(int argc,char *argv[])
 						full_url=str;
 					} else if (x==isa_cols[ISACOL_Status]) {
 						if (strlen(str)>=sizeof(code)) {
-							debuga(_("Maybe you have a broken access code in your %s file\n"),arq);
+							debuga(_("Invalid access code in file \"%s\"\n"),arq);
 							exit(EXIT_FAILURE);
 						}
 						strcpy(code,str);
@@ -1247,15 +1252,15 @@ int main(int argc,char *argv[])
 				}
 				getword_start(&gwarea,data);
 				if (getword_atoll(&iyear,&gwarea,'-')<0){
-					debuga(_("Maybe you have a broken year in your %s file\n"),arq);
+					debuga(_("Invalid year in file \"%s\"\n"),arq);
 					exit(EXIT_FAILURE);
 				}
 				if (getword_atoll(&imonth,&gwarea,'-')<0){
-					debuga(_("Maybe you have a broken month in your %s file\n"),arq);
+					debuga(_("Invalid month in file \"%s\"\n"),arq);
 					exit(EXIT_FAILURE);
 				}
 				if (getword_atoll(&iday,&gwarea,'\0')<0){
-					debuga(_("Maybe you have a broken day in your %s file\n"),arq);
+					debuga(_("Invalid day in file \"%s\"\n"),arq);
 					exit(EXIT_FAILURE);
 				}
 
@@ -1264,7 +1269,7 @@ int main(int argc,char *argv[])
 				if (isa_cols[ISACOL_Time]>=0) {
 					if (sscanf(hora,"%d:%d:%d",&tt.tm_hour,&tt.tm_min,&tt.tm_sec)!=3 || tt.tm_hour<0 || tt.tm_hour>=24 ||
 							tt.tm_min<0 || tt.tm_min>=60 || tt.tm_sec<0 || tt.tm_sec>=60) {
-						debuga(_("Invalid time found in %s\n"),arq);
+						debuga(_("Invalid time in file \"%s\"\n"),arq);
 						exit(EXIT_FAILURE);
 					}
 				}
@@ -1455,7 +1460,7 @@ int main(int argc,char *argv[])
 			if (!ufile) {
 				ufile=malloc(sizeof(*ufile));
 				if (!ufile) {
-					debuga(_("Not enough memory to store the user %s\n"),user);
+					debuga(_("Not enough memory to store user %s\n"),user);
 					exit(EXIT_FAILURE);
 				}
 				memset(ufile,0,sizeof(*ufile));
@@ -1484,7 +1489,7 @@ int main(int argc,char *argv[])
 						if (ufile1->file!=NULL) {
 							if (x>=maxopenfiles) {
 								if (fclose(ufile1->file)==EOF) {
-									debuga(_("Failed to close the log file of user %s - %s\n"),ufile1->user->id,strerror(errno));
+									debuga(_("Failed to close file \"%s\": %s\n"),ufile1->user->id,strerror(errno));
 									exit(EXIT_FAILURE);
 								}
 								ufile1->file=NULL;
@@ -1494,23 +1499,24 @@ int main(int argc,char *argv[])
 					}
 				}
 				if (snprintf (tmp3, sizeof(tmp3), "%s/%s.user_unsort", tmp, ufile->user->filename)>=sizeof(tmp3)) {
-					debuga(_("Temporary user file name too long: %s/%s.user_unsort\n"), tmp, ufile->user->filename);
+					debuga(_("Path too long: "));
+					debuga_more("%s/%s.user_unsort\n", tmp, ufile->user->filename);
 					exit(EXIT_FAILURE);
 				}
 				if ((ufile->file = MY_FOPEN (tmp3, "a")) == NULL) {
-					debuga(_("(log) Cannot open temporary file: %s - %s\n"), tmp3, strerror(errno));
+					debugapos("log",_("Cannot open file \"%s\": %s\n"), tmp3, strerror(errno));
 					exit (1);
 				}
 			}
 
-			if (fprintf(ufile->file, "%s\t%s\t%s\t%s\t%"PRIi64"\t%s\t%ld\t%s\n",dia,hora,ip,url,nbytes,code,elap_time,smartfilter)<=0) {
+			if (fprintf(ufile->file, "%s\t%s\t%s\t%s\t%"PRIi64"\t%s\t%ld\t%s\n",dia,hora,ip,url,(int64_t)nbytes,code,elap_time,smartfilter)<=0) {
 				debuga(_("Write error in the log file of user %s\n"),user);
 				exit(EXIT_FAILURE);
 			}
 			records_kept++;
 
 			if(fp_log && ilf!=ILF_Sarg)
-				fprintf(fp_log, "%s\t%s\t%s\t%s\t%s\t%"PRIi64"\t%s\t%ld\t%s\n",dia,hora,user,ip,url,nbytes,code,elap_time,smartfilter);
+				fprintf(fp_log, "%s\t%s\t%s\t%s\t%s\t%"PRIi64"\t%s\t%ld\t%s\n",dia,hora,user,ip,url,(int64_t)nbytes,code,elap_time,smartfilter);
 
 			totregsg++;
 
@@ -1519,7 +1525,7 @@ int main(int argc,char *argv[])
 
 				if ( ! fp_Download_Unsort ) {
 					if ((fp_Download_Unsort = MY_FOPEN ( sz_Download_Unsort, "a")) == NULL) {
-						debuga(_("(log) Cannot open temporary file: %s - %s\n"),sz_Download_Unsort, strerror(errno));
+						debugapos("log",_("Cannot open file \"%s\": %s\n"),sz_Download_Unsort, strerror(errno));
 						exit (1);
 					}
 				}
@@ -1561,7 +1567,7 @@ int main(int argc,char *argv[])
 				printf("FUNC=\t%s\n",fun);
 				printf("URL=\t%s\n",url);
 				printf("CODE=\t%s\n",code);
-				printf("LEN=\t%"PRIi64"\n",nbytes);
+				printf("LEN=\t%"PRIi64"\n",(int64_t)nbytes);
 			}
 		}
 		if (!from_stdin) {
@@ -1569,8 +1575,10 @@ int main(int argc,char *argv[])
 				pclose(fp_in);
 			else {
 				fclose(fp_in);
-				if( ShowReadStatistics )
-					printf(_("SARG: Records in file: %lu, reading: %3.2f%%\n"),recs1, (float) 100 );
+				if( ShowReadStatistics ) {
+					printf(_("SARG: Records in file: %lu, reading: %3.2lf%%"),recs1,100.);
+					putchar('\n');
+				}
 			}
 		}
 	}
@@ -1644,8 +1652,10 @@ int main(int argc,char *argv[])
 		debugaz(_("period=%s\n"),period.text);
 	}
 
-	if(debug)
-		debuga(_("Period: %s\n"),period.text);
+	if(debug) {
+		debuga(_("Period: %s"),period.text);
+		debuga_more("\n");
+	}
 
 	if(fp_denied)
 		fclose(fp_denied);
@@ -1662,11 +1672,12 @@ int main(int argc,char *argv[])
 		strftime(val2,sizeof(val2),"%d%m%Y",&period.start);
 		strftime(val1,sizeof(val1),"%d%m%Y",&period.end);
 		if (snprintf(val4,sizeof(val4),"%s/sarg-%s_%s-%s_%s.log",ParsedOutputLog,val2,start_hour,val1,end_hour)>=sizeof(val4)) {
-			debuga(_("File name too long: %s/sarg-%s_%s-%s_%s.log\n"),ParsedOutputLog,val2,start_hour,val1,end_hour);
+			debuga(_("Path too long: "));
+			debuga_more("%s/sarg-%s_%s-%s_%s.log\n",ParsedOutputLog,val2,start_hour,val1,end_hour);
 			exit(EXIT_FAILURE);
 		}
 		if (rename(arq_log,val4)) {
-			debuga(_("failed to rename %s to %s - %s\n"),arq_log,val4,strerror(errno));
+			debuga(_("Failed to rename \"%s\" into \"%s\": %s\n"),arq_log,val4,strerror(errno));
 		} else {
 			strcpy(arq_log,val4);
 
@@ -1676,7 +1687,9 @@ int main(int argc,char *argv[])
 				necessary around the command name, put them in the configuration file.
 				*/
 				if (snprintf(val1,sizeof(val1),"%s \"%s\"",ParsedOutputLogCompress,arq_log)>=sizeof(val1)) {
-					debuga(_("Command too long: %s \"%s\"\n"),ParsedOutputLogCompress,arq_log);
+					/* TRANSLATORS: The message is followed by the command that's too long. */
+					debuga(_("Command too long: "));
+					debuga_more("%s \"%s\"\n",ParsedOutputLogCompress,arq_log);
 					exit(EXIT_FAILURE);
 				}
 				cstatus=system(val1);
@@ -1693,7 +1706,8 @@ int main(int argc,char *argv[])
 
 	if(DataFile[0] == '\0' && (ReportType & REPORT_TYPE_DENIED) != 0) {
 		if (snprintf(csort,sizeof(csort),"sort -T \"%s\" -t \"\t\" -k 3,3 -k 5,5 -o \"%s\" \"%s\"",tmp,denied_sort,denied_unsort)>=sizeof(csort)) {
-			debuga(_("Sort command too long when sorting file \"%s\" to \"%s\"\n"),denied_unsort,denied_sort);
+			debuga(_("Command too long: "));
+			debuga_more("sort -T \"%s\" -t \"\t\" -k 3,3 -k 5,5 -o \"%s\" \"%s\"",tmp,denied_sort,denied_unsort);
 			exit(EXIT_FAILURE);
 		}
 		cstatus=system(csort);
@@ -1764,27 +1778,27 @@ static void getusers(const char *pwdfile, int debug)
 		debuga(_("Loading password file from %s\n"),pwdfile);
 
 	if ((fp_usr = fopen(pwdfile, "r")) == NULL) {
-		debuga(_("(getusers) Cannot open file %s - %s\n"),pwdfile,strerror(errno));
+		debugapos("getusers",_("Cannot open file \"%s\": %s\n"),pwdfile,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if (fseek(fp_usr, 0, SEEK_END)==-1) {
-		debuga(_("Failed to move till the end of the users file %s: %s\n"),pwdfile,strerror(errno));
+		debuga(_("Failed to move till the end of file \"%s\": %s\n"),pwdfile,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	nreg = ftell(fp_usr);
 	if (nreg<0) {
-		debuga(_("Cannot get the size of file %s\n"),pwdfile);
+		debuga(_("Cannot get the size of file \"%s\": %s\n"),pwdfile,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	nreg = nreg+5000;
 	if (fseek(fp_usr, 0, SEEK_SET)==-1) {
-		debuga(_("Failed to rewind the users file %s: %s\n"),pwdfile,strerror(errno));
+		debuga(_("Failed to rewind file \"%s\": %s\n"),pwdfile,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if((userfile=(char *) malloc(nreg))==NULL){
-		debuga(_("malloc error (%ld)\n"),nreg);
+		debuga(_("malloc failed to allocate %ld bytes\n"),nreg);
 		exit(EXIT_FAILURE);
 	}
 
@@ -1794,7 +1808,7 @@ static void getusers(const char *pwdfile, int debug)
 	while(fgets(buf,sizeof(buf),fp_usr)!=NULL) {
 		str=strchr(buf,':');
 		if (!str) {
-			debuga(_("You have an invalid user in your %s file\n"),pwdfile);
+			debuga(_("Invalid user in file \"%s\"\n"),pwdfile);
 			exit(EXIT_FAILURE);
 		}
 		str[1]='\0';
