@@ -80,7 +80,7 @@ static void parse_log(FILE *fp_ou,char *buf)
 			}
 			if(strcmp(leks,"end") != 0) {
 				if (getword_limit(res,sizeof(res),&gwarea,sep[0])<0) {
-					debuga(_("Parsing of tag \"%s\" in redirector log %s returned no result\n"),leks,wentp);
+					debuga(_("Parsing of tag \"%s\" in redirector log \"%s\" returned no result\n"),leks,wentp);
 					RedirectorErrors++;
 					return;
 				}
@@ -120,7 +120,7 @@ static void parse_log(FILE *fp_ou,char *buf)
 					strcpy(ip,res);
 				} else if(strcmp(leks,"user") == 0) {
 					if (strlen(res)>=sizeof(user)) {
-						debuga(_("User ID too long in redirector log file %s\n"),wentp);
+						debuga(_("User ID too long in redirector log file \"%s\"\n"),wentp);
 						RedirectorErrors++;
 						return;
 					}
@@ -137,7 +137,7 @@ static void parse_log(FILE *fp_ou,char *buf)
 	} else {
 		if (getword_atoll(&lyear,&gwarea,'-')<0 || getword_atoll(&lmon,&gwarea,'-')<0 ||
 				getword_atoll(&lday,&gwarea,' ')<0) {
-			debuga(_("Invalid date found in file %s\n"),wentp);
+			debuga(_("Invalid date in file \"%s\"\n"),wentp);
 			RedirectorErrors++;
 			return;
 		}
@@ -145,7 +145,7 @@ static void parse_log(FILE *fp_ou,char *buf)
 		mon=(int)lmon;
 		day=(int)lday;
 		if (getword(hour,sizeof(hour),&gwarea,' ')<0) {
-			debuga(_("Invalid time found in file %s\n"),wentp);
+			debuga(_("Invalid time in file \"%s\"\n"),wentp);
 			RedirectorErrors++;
 			return;
 		}
@@ -155,22 +155,22 @@ static void parse_log(FILE *fp_ou,char *buf)
 			return;
 		}
 		if (getword(list,sizeof(list),&gwarea,'/')<0) {
-			debuga(_("Invalid redirected list in file %s\n"),wentp);
+			debuga(_("Invalid redirected list in file \"%s\"\n"),wentp);
 			RedirectorErrors++;
 			return;
 		}
 		if (getword_skip(MAXLEN,&gwarea,' ')<0 || getword_limit(full_url,sizeof(full_url),&gwarea,' ')<0) {
-			debuga(_("Invalid URL in file %s\n"),wentp);
+			debuga(_("Invalid url in file \"%s\"\n"),wentp);
 			RedirectorErrors++;
 			return;
 		}
 		if (getword(ip,sizeof(ip),&gwarea,'/')<0) {
-			debuga(_("Invalid source IP in file %s\n"),wentp);
+			debuga(_("Invalid source IP in file \"%s\"\n"),wentp);
 			RedirectorErrors++;
 			return;
 		}
 		if (getword_skip(MAXLEN,&gwarea,' ')<0 || getword(user,sizeof(user),&gwarea,' ')<0) {
-			debuga(_("Invalid user in file %s\n"),wentp);
+			debuga(_("Invalid user in file \"%s\"\n"),wentp);
 			RedirectorErrors++;
 			return;
 		}
@@ -227,7 +227,7 @@ static void read_log(const char *wentp, FILE *fp_ou,int dfrom,int duntil)
 	longline line;
 
 	if(debug) {
-		debuga(_("Reading redirector log file %s\n"),wentp);
+		debuga(_("Reading redirector log file \"%s\"\n"),wentp);
 	}
 
 	/* With squidGuard, you can log groups in only one log file.
@@ -264,12 +264,12 @@ static void read_log(const char *wentp, FILE *fp_ou,int dfrom,int duntil)
 	}
 
 	if ((fp_in=fopen(wentp,"r"))==NULL) {
-		debuga(_("(squidguard) Cannot open log file %s\n"),wentp);
+		debugapos("squidguard",_("Cannot open file \"%s\": %s\n"),wentp,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if ((line=longline_create())==NULL) {
-		debuga(_("Not enough memory to read the redirector log\n"));
+		debuga(_("Not enough memory to read file \"%s\"\n"),wentp);
 		exit(EXIT_FAILURE);
 	}
 
@@ -307,7 +307,7 @@ void redirector_log(void)
 	snprintf(guard_in,sizeof(guard_in),"%s/redirector.int_unsort",tmp);
 	snprintf(redirector_sorted,sizeof(redirector_sorted),"%s/redirector.int_log",tmp);
 	if((fp_ou=fopen(guard_in,"a"))==NULL) {
-		debuga(_("(squidguard) Cannot open log file %s\n"),guard_in);
+		debugapos("squidguard",_("Cannot open file \"%s\": %s\n"),guard_in,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -324,7 +324,7 @@ void redirector_log(void)
 		}
 
 		if((fp_guard=fopen(SquidGuardConf,"r"))==NULL) {
-			debuga(_("(squidguard) Cannot open log file %s\n"),SquidGuardConf);
+			debugapos("squidguard",_("Cannot open file \"%s\": %s\n"),SquidGuardConf,strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 
@@ -385,11 +385,12 @@ void redirector_log(void)
 	}
 
 	if(debug) {
-		debuga(_("Sorting file: %s\n"),redirector_sorted);
+		debuga(_("Sorting file \"%s\"\n"),redirector_sorted);
 	}
 
 	if (snprintf(tmp6,sizeof(tmp6),"sort -t \"\t\" -k 1,1 -k 2,2 -k 4,4 \"%s\" -o \"%s\"",guard_in, redirector_sorted)>=sizeof(tmp6)) {
-		debuga(_("Sort command too long when sorting file \"%s\" to \"%s\"\n"),guard_in,redirector_sorted);
+		debuga(_("Command too long: "));
+		debuga_more("sort -t \"\t\" -k 1,1 -k 2,2 -k 4,4 \"%s\" -o \"%s\"",guard_in, redirector_sorted);
 		exit(EXIT_FAILURE);
 	}
 	cstatus=system(tmp6);
@@ -452,17 +453,17 @@ void redirector_report(void)
 	snprintf(report,sizeof(report),"%s/redirector.html",outdirname);
 
 	if((fp_in=fopen(redirector_sorted,"r"))==NULL) {
-		debuga(_("(squidguard) Cannot open log file %s\n"),redirector_sorted);
+		debugapos("squidguard",_("Cannot open file \"%s\": %s\n"),redirector_sorted,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if((fp_ou=fopen(report,"w"))==NULL) {
-		debuga(_("(squidguard) Cannot open log file %s\n"),report);
+		debugapos("squidguard",_("Cannot open file \"%s\": %s\n"),report,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if ((line=longline_create())==NULL) {
-		debuga(_("Not enough memory to read the processed redirector log\n"));
+		debuga(_("Not enough memory to read file \"%s\"\n"),redirector_sorted);
 		exit(EXIT_FAILURE);
 	}
 
@@ -479,33 +480,33 @@ void redirector_report(void)
 	while((buf=longline_read(fp_in,line))!=NULL) {
 		getword_start(&gwarea,buf);
 		if (getword(user,sizeof(user),&gwarea,'\t')<0) {
-			debuga(_("Invalid user in file %s\n"),redirector_sorted);
+			debuga(_("Invalid user found in file \"%s\"\n"),redirector_sorted);
 			exit(EXIT_FAILURE);
 		}
 		if (getword_atoll(&data2,&gwarea,'\t')<0) {
-			debuga(_("Invalid date in file %s\n"),redirector_sorted);
+			debuga(_("Invalid date in file \"%s\"\n"),redirector_sorted);
 			exit(EXIT_FAILURE);
 		}
 		if (getword(hora,sizeof(hora),&gwarea,'\t')<0) {
-			debuga(_("Invalid time in file %s\n"),redirector_sorted);
+			debuga(_("Invalid time in file \"%s\"\n"),redirector_sorted);
 			exit(EXIT_FAILURE);
 		}
 		if (getword(ip,sizeof(ip),&gwarea,'\t')<0) {
-			debuga(_("Invalid IP address in file %s\n"),redirector_sorted);
+			debuga(_("Invalid IP address in file \"%s\"\n"),redirector_sorted);
 			exit(EXIT_FAILURE);
 		}
 		if (getword_ptr(buf,&url,&gwarea,'\t')<0) {
-			debuga(_("Invalid URL in file %s\n"),redirector_sorted);
+			debuga(_("Invalid url in file \"%s\"\n"),redirector_sorted);
 			exit(EXIT_FAILURE);
 		}
 		if (getword(rule,sizeof(rule),&gwarea,'\n')<0) {
-			debuga(_("Invalid rule in file %s\n"),redirector_sorted);
+			debuga(_("Invalid rule in file \"%s\"\n"),redirector_sorted);
 			exit(EXIT_FAILURE);
 		}
 
 		uinfo=userinfo_find_from_id(user);
 		if (!uinfo) {
-			debuga(_("Unknown user ID %s in file %s\n"),user,redirector_sorted);
+			debuga(_("Unknown user ID %s in file \"%s\"\n"),user,redirector_sorted);
 			exit(EXIT_FAILURE);
 		}
 
@@ -571,9 +572,9 @@ void redirector_report(void)
 	
 	fputs("</div>\n",fp_ou);
 	if (write_html_trailer(fp_ou)<0)
-		debuga(_("Write error in file %s\n"),report);
+		debuga(_("Write error in file \"%s\"\n"),report);
 	if (fclose(fp_ou)==EOF)
-		debuga(_("Failed to close file %s - %s\n"),report,strerror(errno));
+		debuga(_("Failed to close file \"%s\": %s\n"),report,strerror(errno));
 
 	if (!KeepTempLog && unlink(redirector_sorted)) {
 		debuga(_("Cannot delete \"%s\": %s\n"),redirector_sorted,strerror(errno));
