@@ -61,12 +61,13 @@ void report_day(const struct userinfostruct *uinfo)
 	if(access(wdirname, R_OK) != 0) return;
 
 	if (snprintf(arqout,sizeof(arqout),"%s/%s/d%s.html",outdirname,uinfo->filename,uinfo->filename)>=sizeof(arqout)) {
-		debuga(_("Output file name too long: %s/%s/d%s.html\n"),outdirname,uinfo->filename,uinfo->filename);
+		debuga(_("Path too long: "));
+		debuga_more("%s/%s/d%s.html\n",outdirname,uinfo->filename,uinfo->filename);
 		exit(EXIT_FAILURE);
 	}
 
 	if((fp_in=fopen(wdirname,"r"))==NULL) {
-		debuga(_("(repday) Cannot open log file %s\n"),wdirname);
+		debugapos("repday",_("Cannot open file \"%s\": %s\n"),wdirname,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -78,7 +79,7 @@ void report_day(const struct userinfostruct *uinfo)
 		fixendofline(buf);
 		getword_start(&gwarea,buf);
 		if (getword(data,sizeof(data),&gwarea,'\t')<0) {
-			debuga(_("Invalid date in file %s\n"),wdirname);
+			debuga(_("Invalid date in file \"%s\"\n"),wdirname);
 			exit(EXIT_FAILURE);
 		}
 		if (sscanf(data,"%d/%d/%d",&day,&month,&year)!=3) continue;
@@ -87,14 +88,14 @@ void report_day(const struct userinfostruct *uinfo)
 		for (dayidx=0 ; dayidx<ndaylist && daynum!=daylist[dayidx] ; dayidx++);
 		if (dayidx>=ndaylist) {
 			if (dayidx>=sizeof(daylist)/sizeof(*daylist)) {
-				debuga(_("Too many different dates in %s\n"),wdirname);
+				debuga(_("Too many different dates in \"%s\"\n"),wdirname);
 				exit(EXIT_FAILURE);
 			}
 			daylist[ndaylist++]=daynum;
 		}
 
 		if (getword_atoll(&hour,&gwarea,'\t')<0) {
-			debuga(_("Invalid time in file %s\n"),wdirname);
+			debuga(_("Invalid time in file \"%s\"\n"),wdirname);
 			exit(EXIT_FAILURE);
 		}
 		ihour=(int)hour;
@@ -103,14 +104,14 @@ void report_day(const struct userinfostruct *uinfo)
 		if ((datetimeby & DATETIME_BYTE)!=0) {
 			colsep=((datetimeby & DATETIME_ELAP)!=0) ? '\t' : '\0';
 			if (getword_atoll(&bytes,&gwarea,colsep)<0) {
-				debuga(_("Invalid number of bytes in file %s\n"),wdirname);
+				debuga(_("Invalid number of bytes in file \"%s\"\n"),wdirname);
 				exit(EXIT_FAILURE);
 			}
 			tbytes[i]+=bytes;
 		}
 		if ((datetimeby & DATETIME_ELAP)!=0) {
 			if (getword_atoll(&elap,&gwarea,'\0')<0) {
-				debuga(_("Invalid elapsed time in file %s\n"),wdirname);
+				debuga(_("Invalid elapsed time in file \"%s\"\n"),wdirname);
 				exit(EXIT_FAILURE);
 			}
 			telap[i]+=elap;
@@ -119,7 +120,7 @@ void report_day(const struct userinfostruct *uinfo)
 	fclose(fp_in);
 
 	if((fp_ou=fopen(arqout,"w"))==NULL) {
-		debuga(_("(repday) Cannot open log file %s\n"),arqout);
+		debugapos("repday",_("Cannot open file \"%s\": %s\n"),arqout,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -242,8 +243,8 @@ void report_day(const struct userinfostruct *uinfo)
 	}
 
 	if (write_html_trailer(fp_ou)<0)
-		debuga(_("Write error in file %s\n"),arqout);
+		debuga(_("Write error in file \"%s\"\n"),arqout);
 	if (fclose(fp_ou)==EOF)
-		debuga(_("Failed to close file %s - %s\n"),arqout,strerror(errno));
+		debuga(_("Failed to close file \"%s\": %s\n"),arqout,strerror(errno));
 	return;
 }
