@@ -62,17 +62,17 @@ void useragent(void)
 	sprintf(tmp2,"%s/squagent.int_log",tmp);
 
 	if((fp_in=fopen(UserAgentLog,"r"))==NULL) {
-		debuga(_("(useragent) Cannot open file %s\n"),UserAgentLog);
+		debugapos("useragent",_("Cannot open file \"%s\": %s\n"),UserAgentLog,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if((fp_ou=fopen(tmp3,"w"))==NULL) {
-		debuga(_("(useragent) Cannot open file %s\n"),tmp3);
+		debugapos("useragent",_("Cannot open file \"%s\": %s\n"),tmp3,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if(debug) {
-		debuga(_("Reading useragent log: %s\n"),UserAgentLog);
+		debuga(_("Reading useragent log \"%s\"\n"),UserAgentLog);
 	}
 
 	while(fgets(buf,sizeof(buf),fp_in)!=NULL) {
@@ -80,13 +80,13 @@ void useragent(void)
 		getword_start(&gwarea,buf);
 		if (getword(ip,sizeof(ip),&gwarea,' ')<0 || getword_skip(MAXLEN,&gwarea,'[')<0 ||
 		    getword(data,sizeof(data),&gwarea,' ')<0) {
-			debuga(_("Maybe you have a broken record or garbage in your %s file\n"),UserAgentLog);
+			debuga(_("Invalid record in file \"%s\"\n"),UserAgentLog);
 			exit(EXIT_FAILURE);
 		}
 		getword_start(&gwarea1,data);
 		if (getword(day,sizeof(day),&gwarea1,'/')<0 || getword(month,sizeof(month),&gwarea1,'/')<0 ||
 		    getword(year,sizeof(year),&gwarea1,':')<0) {
-			debuga(_("Maybe you have a broken date in your %s file\n"),UserAgentLog);
+			debuga(_("Invalid date in file \"%s\"\n"),UserAgentLog);
 			exit(EXIT_FAILURE);
 		}
 		buildymd(day,month,year,wdate);
@@ -97,13 +97,13 @@ void useragent(void)
 			strcpy(idate,data);
 		strcpy(fdate,data);
 		if (getword_skip(MAXLEN,&gwarea,'"')<0 || getword(agent,sizeof(agent),&gwarea,'"')<0) {
-			debuga(_("Maybe you have a broken useragent entry in your %s file\n"),UserAgentLog);
+			debuga(_("Invalid useragent in file \"%s\"\n"),UserAgentLog);
 			exit(EXIT_FAILURE);
 		}
 
 		if(gwarea.current[0]!='\0') {
 			if (getword_skip(MAXLEN,&gwarea,' ')<0 || getword(user,sizeof(user),&gwarea,'\n')<0) {
-				debuga(_("Maybe you have a broken record or garbage in your %s file\n"),UserAgentLog);
+				debuga(_("Invalid record in file \"%s\"\n"),UserAgentLog);
 				exit(EXIT_FAILURE);
 			}
 			if(user[0] == '-')
@@ -124,16 +124,17 @@ void useragent(void)
 
 	fclose(fp_in);
 	if (fclose(fp_ou)==EOF) {
-		debuga(_("Failed to close file %s - %s\n"),tmp3,strerror(errno));
+		debuga(_("Failed to close file \"%s\": %s\n"),tmp3,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if(debug) {
-		debuga(_("Sorting file: %s\n"),tmp2);
+		debuga(_("Sorting file \"%s\"\n"),tmp2);
 	}
 
 	if (snprintf(csort,sizeof(csort),"sort -n -t \"\t\" -k 3,3 -k 2,2 -k 1,1 -o \"%s\" \"%s\"",tmp2,tmp3)>=sizeof(csort)) {
-		debuga(_("Sort command too long when sorting file \"%s\" to \"%s\"\n"),tmp2,tmp3);
+		debuga(_("Command too long: "));
+		debuga_more("sort -n -t \"\t\" -k 3,3 -k 2,2 -k 1,1 -o \"%s\" \"%s\"",tmp2,tmp3);
 		exit(EXIT_FAILURE);
 	}
 	cstatus=system(csort);
@@ -143,7 +144,7 @@ void useragent(void)
 		exit(EXIT_FAILURE);
 	}
 	if((fp_in=fopen(tmp2,"r"))==NULL) {
-		debuga(_("(useragent) Cannot open file %s\n"),tmp2);
+		debugapos("useragent",_("Cannot open file \"%s\": %s\n"),tmp2,strerror(errno));
 		debuga(_("sort command: %s\n"),csort);
 		exit(EXIT_FAILURE);
 	}
@@ -155,7 +156,7 @@ void useragent(void)
 
 	snprintf(hfile,sizeof(hfile),"%s/useragent.html", outdirname);
 	if((fp_ht=fopen(hfile,"w"))==NULL) {
-		debuga(_("(useragent) Cannot open file %s\n"),hfile);
+		debugapos("useragent",_("Cannot open file \"%s\": %s\n"),hfile,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -177,7 +178,7 @@ void useragent(void)
 	while(fgets(buf,sizeof(buf),fp_in)!=NULL) {
 		getword_start(&gwarea,buf);
 		if (getword(ip,sizeof(ip),&gwarea,'\t')<0) {
-			debuga(_("There is an invalid IP address in file %s\n"),tmp2);
+			debuga(_("Invalid IP address in file \"%s\"\n"),tmp2);
 			exit(EXIT_FAILURE);
 		}
 
@@ -190,11 +191,11 @@ void useragent(void)
 		}
 
 		if (getword(agent,sizeof(agent),&gwarea,'\t')<0) {
-			debuga(_("There is an invalid useragent in file %s\n"),tmp2);
+			debuga(_("Invalid useragent in file \"%s\"\n"),tmp2);
 			exit(EXIT_FAILURE);
 		}
 		if (getword(user,sizeof(user),&gwarea,'\t')<0) {
-			debuga(_("There is an invalid user ID in file %s\n"),tmp2);
+			debuga(_("Invalid user ID in file \"%s\"\n"),tmp2);
 			exit(EXIT_FAILURE);
 		}
 
@@ -216,7 +217,8 @@ void useragent(void)
 	fclose(fp_in);
 
 	if (snprintf(csort,sizeof(csort),"sort -t \"\t\" -k 2,2 -o \"%s\" \"%s\"",tmp3,tmp2)>=sizeof(csort)) {
-		debuga(_("Sort command too long when sorting file \"%s\" to \"%s\"\n"),tmp2,tmp3);
+		debuga(_("Command too long: "));
+		debuga_more("sort -t \"\t\" -k 2,2 -o \"%s\" \"%s\"",tmp3,tmp2);
 		exit(EXIT_FAILURE);
 	}
 	cstatus=system(csort);
@@ -226,7 +228,7 @@ void useragent(void)
 		exit(EXIT_FAILURE);
 	}
 	if((fp_in=fopen(tmp3,"r"))==NULL) {
-		debuga(_("(useragent) Cannot open file %s\n"),tmp3);
+		debugapos("useragent",_("Cannot open file \"%s\": %s\n"),tmp3,strerror(errno));
 		debuga(_("sort command: %s\n"),csort);
 		exit(EXIT_FAILURE);
 	}
@@ -237,7 +239,7 @@ void useragent(void)
 	}
 
 	if((fp_ou=fopen(tmp2,"w"))==NULL) {
-		debuga(_("(useragent) Cannot open file %s\n"),tmp2);
+		debugapos("useragent",_("Cannot open file \"%s\": %s\n"),tmp2,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -247,11 +249,11 @@ void useragent(void)
 	while(fgets(buf,sizeof(buf),fp_in)!=NULL) {
 		getword_start(&gwarea,buf);
 		if (getword(ip,sizeof(ip),&gwarea,'\t')<0) {
-			debuga(_("There is an invalid IP address in file %s\n"),tmp3);
+			debuga(_("Invalid IP address in file \"%s\"\n"),tmp3);
 			exit(EXIT_FAILURE);
 		}
 		if (getword(agent,sizeof(agent),&gwarea,'\t')<0) {
-			debuga(_("There is an invalid useragent in file %s\n"),tmp3);
+			debuga(_("Invalid useragent in file \"%s\"\n"),tmp3);
 			exit(EXIT_FAILURE);
 		}
 
@@ -275,7 +277,7 @@ void useragent(void)
 
 	fclose(fp_in);
 	if (fclose(fp_ou)==EOF) {
-		debuga(_("Failed to close file %s - %s\n"),tmp3,strerror(errno));
+		debuga(_("Failed to close file \"%s\": %s\n"),tmp3,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -285,7 +287,8 @@ void useragent(void)
 	}
 
 	if (snprintf(csort,sizeof(csort),"sort -n -r -k 1,1 -o \"%s\" \"%s\"",tmp3,tmp2)>=sizeof(csort)) {
-		debuga(_("Sort command too long when sorting file \"%s\" to \"%s\"\n"),tmp2,tmp3);
+		debuga(_("Command too long: "));
+		debuga_more("sort -n -r -k 1,1 -o \"%s\" \"%s\"",tmp3,tmp2);
 		exit(EXIT_FAILURE);
 	}
 	cstatus=system(csort);
@@ -295,7 +298,7 @@ void useragent(void)
 		exit(EXIT_FAILURE);
 	}
 	if((fp_in=fopen(tmp3,"r"))==NULL) {
-		debuga(_("(useragent) Cannot open file %s\n"),tmp3);
+		debugapos("useragent",_("Cannot open file \"%s\": %s\n"),tmp3,strerror(errno));
 		debuga(_("sort command: %s\n"),csort);
 		exit(EXIT_FAILURE);
 	}
@@ -315,7 +318,7 @@ void useragent(void)
 		fixendofline(buf);
 		getword_start(&gwarea,buf);
 		if (getword(tagent,sizeof(tagent),&gwarea,' ')<0) {
-			debuga(_("There is an invalid useragent in file %s\n"),tmp3);
+			debuga(_("Invalid useragent in file \"%s\"\n"),tmp3);
 			exit(EXIT_FAILURE);
 		}
 		nagent=atoi(tagent);
@@ -329,9 +332,9 @@ void useragent(void)
 
 	fputs("</table></div>\n",fp_ht);
 	if (write_html_trailer(fp_ht)<0)
-		debuga(_("Write error in file %s\n"),hfile);
+		debuga(_("Write error in file \"%s\"\n"),hfile);
 	if (fclose(fp_ht)==EOF)
-		debuga(_("Failed to close file %s - %s\n"),hfile,strerror(errno));
+		debuga(_("Failed to close file \"%s\": %s\n"),hfile,strerror(errno));
 
 	if (!KeepTempLog && unlink(tmp3)) {
 		debuga(_("Cannot delete \"%s\": %s\n"),tmp3,strerror(errno));
