@@ -41,6 +41,8 @@ static char mtab1[12][4]={"Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep",
 //! The list of the HTTP codes to exclude from the report.
 static char *excludecode=NULL;
 
+extern char *CurrentLocale;
+
 #if USE_GETWORD_BACKTRACE
 static void getword_backtrace(void)
 {
@@ -52,6 +54,9 @@ static void getword_backtrace(void)
 	if (n<=0) return;
 	calls=backtrace_symbols(buffer,n);
 	if (calls) {
+		/* TRANSLATORS: "getword" is the function displaying
+		 * the backtrace leading to its execution.
+		 */
 		debuga(_("getword backtrace:\n"));
 		for (i=0 ; i<n ; i++) {
 			fprintf(stderr,"SARG: %d:%s\n",i+1,calls[i]);
@@ -83,11 +88,12 @@ int getword(char *word, int limit, struct getwordstruct *gwarea, char stop)
 
 	for(x=0;((gwarea->current[x]) && (gwarea->current[x] != stop ));x++) {
 		if(x>=limit) {
-			debuga(_("getword loop detected after %d bytes.\n"),x);
+			/* TRANSLATORS: %s is the name of the function reporting this error.
+			 */
+			debuga(_("Loop detected in %s after %d bytes.\n"),__func__,x);
 			debuga(_("Line=\"%s\"\n"),gwarea->beginning);
 			debuga(_("Record=\"%s\"\n"),gwarea->current);
 			debuga(_("searching for \'x%x\'\n"),stop);
-			//debuga(_("Maybe you have a broken record or garbage in your access.log file.\n"));
 			word[(limit>0) ? limit-1 : 0]='\0';
 #if USE_GETWORD_BACKTRACE
 			getword_backtrace();
@@ -124,11 +130,12 @@ int getword_multisep(char *word, int limit, struct getwordstruct *gwarea, char s
 
 	for(x=0;((gwarea->current[x]) && (gwarea->current[x] != stop ));x++) {
 		if(x>=limit) {
-			debuga(_("getword_multisep loop detected.\n"));
+			/* TRANSLATORS: %s is the name of the function reporting this error.
+			 */
+			debuga(_("Loop detected in %s after %d bytes.\n"),__func__,x);
 			debuga(_("Line=\"%s\"\n"),gwarea->beginning);
 			debuga(_("Record=\"%s\"\n"),gwarea->current);
 			debuga(_("searching for \'x%x\'\n"),stop);
-			//debuga(_("Maybe you have a broken record or garbage in your access.log file.\n"));
 			if (limit>0) word[limit-1]='\0';
 #if USE_GETWORD_BACKTRACE
 			getword_backtrace();
@@ -151,11 +158,12 @@ int getword_skip(int limit, struct getwordstruct *gwarea, char stop)
 
 	for(x=0;(gwarea->current[x] && (gwarea->current[x] != stop ));x++) {
 		if(x>=limit) {
-			debuga(_("getword_skip loop detected after %d bytes.\n"),x);
+			/* TRANSLATORS: %s is the name of the function reporting this error.
+			 */
+			debuga(_("Loop detected in %s after %d bytes.\n"),__func__,x);
 			debuga(_("Line=\"%s\"\n"),gwarea->beginning);
 			debuga(_("Record=\"%s\"\n"),gwarea->current);
 			debuga(_("searching for \'x%x\'\n"),stop);
-			//debuga(_("Maybe you have a broken record or garbage in your access.log file.\n"));
 #if USE_GETWORD_BACKTRACE
 			getword_backtrace();
 #endif
@@ -184,17 +192,21 @@ int getword_atoll(long long int *number, struct getwordstruct *gwarea, char stop
 	for(x=0;isdigit(gwarea->current[x]);x++) {
 		digit=gwarea->current[x]-'0';
 		if (*number >= (LLONG_MAX-digit)/10) {
-			debuga(_("Integer overflow detected in getword_atoll in line %s\n"),gwarea->beginning);
+			/* TRANSLATORS: The first %s is the name of the function displaying
+			 * this message.
+			 */
+			debuga(_("Integer overflow detected in %s in line \"%s\"\n"),__func__,gwarea->beginning);
 			return(-1);
 		}
 		*number=(*number * 10) + digit;
 	}
 	if(gwarea->current[x] && gwarea->current[x]!=stop) {
-		debuga(_("getword_atoll loop detected after %d bytes.\n"),x);
+		/* TRANSLATORS: %s is the name of the function reporting this error.
+		 */
+		debuga(_("Loop detected in %s after %d bytes.\n"),__func__,x);
 		debuga(_("Line=\"%s\"\n"),gwarea->beginning);
 		debuga(_("Record=\"%s\"\n"),gwarea->current);
 		debuga(_("searching for \'x%x\'\n"),stop);
-		//debuga(_("Maybe you have a broken record or garbage in your access.log file.\n"));
 #if USE_GETWORD_BACKTRACE
 		getword_backtrace();
 #endif
@@ -223,17 +235,21 @@ int getword_atoi(int *number, struct getwordstruct *gwarea, char stop)
 	for(x=0;isdigit(gwarea->current[x]);x++) {
 		digit=gwarea->current[x]-'0';
 		if (*number > (INT_MAX-digit)/10) {
-			debuga(_("Integer overflow detected in getword_atoi in line %s\n"),gwarea->beginning);
+			/* TRANSLATORS: The first %s is the name of the function displaying
+			 * this message.
+			 */
+			debuga(_("Integer overflow detected in %s in line \"%s\"\n"),__func__,gwarea->beginning);
 			return(-1);
 		}
 		*number=(*number * 10) + digit;
 	}
 	if(gwarea->current[x] && gwarea->current[x]!=stop) {
-		debuga(_("getword_atoi loop detected after %d bytes.\n"),x);
+		/* TRANSLATORS: %s is the name of the function reporting this error.
+		 */
+		debuga(_("Loop detected in %s after %d bytes.\n"),__func__,x);
 		debuga(_("Line=\"%s\"\n"),gwarea->beginning);
 		debuga(_("Record=\"%s\"\n"),gwarea->current);
 		debuga(_("searching for \'x%x\'\n"),stop);
-		//debuga(_("Maybe you have a broken record or garbage in your access.log file.\n"));
 #if USE_GETWORD_BACKTRACE
 		getword_backtrace();
 #endif
@@ -314,21 +330,22 @@ void my_mkdir(const char *name)
 	int chars;
 
 	if(!is_absolute(name)) {
-		debuga(_("Invalid path (%s). Please, use absolute paths only.\n"),name);
+		debuga(_("Invalid path \"%s\". Please, use absolute paths only.\n"),name);
 		exit(EXIT_FAILURE);
 	}
 
 	chars=0;
 	for (i=0 ; name[i] ; i++) {
 		if (i>=sizeof(w0)) {
-			debuga(_("directory name too long: %s\n"),name);
+			debuga(_("Path too long: "));
+			debuga_more("%s\n",name);
 			exit(EXIT_FAILURE);
 		}
 		if (chars>0 && name[i] == '/') {
 			w0[i] = '\0';
 			if (access(w0, R_OK) != 0) {
 				if (mkdir(w0,0755)) {
-					debuga(_("Cannot create directory %s - %s\n"),w0,strerror(errno));
+					debuga(_("Cannot create directory \"%s\": %s\n"),w0,strerror(errno));
 					exit(EXIT_FAILURE);
 				}
 			}
@@ -339,7 +356,7 @@ void my_mkdir(const char *name)
 
 	if (access(name, R_OK) != 0) {
 		if (mkdir(name,0755)) {
-			debuga(_("Cannot create directory %s - %s\n"),name,strerror(errno));
+			debuga(_("Cannot create directory \"%s\": %s\n"),name,strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 	}
@@ -393,12 +410,12 @@ int builddia(int day, int month, int year)
 }
 
 
-void buildymd(const char *dia, const char *mes, const char *ano, char *wdata)
+void buildymd(const char *dia, const char *mes, const char *ano, char *wdata,int wdata_size)
 {
 	int nmes;
 
 	nmes=month2num(mes);
-	sprintf(wdata,"%04d%02d%02d",atoi(ano),nmes+1,atoi(dia));
+	snprintf(wdata,wdata_size,"%04d%02d%02d",atoi(ano),nmes+1,atoi(dia));
 }
 
 
@@ -461,6 +478,42 @@ void debuga(const char *msg,...)
 	va_end(ap);
 }
 
+/*!
+Write a debug message to stderr. The message is supposed
+to be displayed after a message from debuga().
+
+\param msg The printf like message to format.
+\param ... The arguments to format in the message.
+*/
+void debuga_more(const char *msg,...)
+{
+	va_list ap;
+
+	va_start(ap,msg);
+	vfprintf(stderr,msg,ap);
+	va_end(ap);
+}
+
+/*!
+Write a debug message to stderr. The message is prefixed by "SARG:" to identify its origin.
+
+\param pos Where, in the source code, this message comes from.
+\param msg The printf like message to format.
+\param ... The arguments to format in the message.
+*/
+void debugapos(const char *pos,const char *msg,...)
+{
+	va_list ap;
+
+	/* TRANSLATORS: This text is printed on the console before any message from
+	 * the debug log with level "debug".
+	 */
+	fputs(_("SARG: "),stderr);
+	fprintf(stderr,"(%s) ",pos);
+	va_start(ap,msg);
+	vfprintf(stderr,msg,ap);
+	va_end(ap);
+}
 
 /*!
 Write a debug message to stderr. The message is prefixed by "SARG: (info)".
@@ -472,6 +525,9 @@ void debugaz(const char *msg,...)
 {
 	va_list ap;
 
+	/* TRANSLATORS: This text is printed on the console before any message from
+	 * the debug log with level "info".
+	 */
 	fputs(_("SARG: (info) "),stderr);
 	va_start(ap,msg);
 	vfprintf(stderr,msg,ap);
@@ -614,18 +670,16 @@ char *fixnum2(long long int value, int n)
 
 char *buildtime(long long int elap)
 {
-	int num = elap / 1000;
+	long int num = elap / 1000LL;
 	int hor = 0;
 	int min = 0;
 	int sec = 0;
-	static char buf[12];
+	static char buf[20];
 
-	buf[0]='\0';
-
-	hor=num / 3600;
-	min=(num % 3600) / 60;
-	sec=num % 60;
-	sprintf(buf,"%02d:%02d:%02d",hor,min,sec);
+	hor=num / 3600L;
+	min=(num % 3600L) / 60L;
+	sec=num % 60L;
+	snprintf(buf,sizeof(buf),"%02d:%02d:%02d",hor,min,sec);
 
 	return(buf);
 }
@@ -647,9 +701,15 @@ int obtdate(const char *dirname, const char *name, char *data)
 	FILE *fp_in;
 	char wdir[MAXLEN];
 
-	sprintf(wdir,"%s%s/sarg-date",dirname,name);
+	if (snprintf(wdir,sizeof(wdir),"%s%s/sarg-date",dirname,name)>=sizeof(wdir)) {
+		debuga(_("Buffer to small to store %s%s/sarg-date"),dirname,name);
+		exit(EXIT_FAILURE);
+	}
 	if ((fp_in = fopen(wdir, "rt")) == 0) {
-		sprintf(wdir,"%s%s/date",dirname,name);
+		if (snprintf(wdir,sizeof(wdir),"%s%s/date",dirname,name)>=sizeof(wdir)) {
+			debuga(_("Buffer to small to store %s%s/date"),dirname,name);
+			exit(EXIT_FAILURE);
+		}
 		if ((fp_in = fopen(wdir, "rt")) == 0) {
 			data[0]='\0';
 			return(-1);
@@ -657,7 +717,9 @@ int obtdate(const char *dirname, const char *name, char *data)
 	}
 
 	if (!fgets(data,80,fp_in)) {
-		debuga(_("Failed to read the date in %s\n"),wdir);
+		/* TRANSLATORS: %s is a file name.
+		 */
+		debuga(_("Failed to read the date in \"%s\"\n"),wdir);
 		exit(EXIT_FAILURE);
 	}
 	fclose(fp_in);
@@ -704,16 +766,24 @@ int obtuser(const char *dirname, const char *name)
 	char tuser[20];
 	int nuser;
 
-	sprintf(wdir,"%s%s/sarg-users",dirname,name);
+	if (snprintf(wdir,sizeof(wdir),"%s%s/sarg-users",dirname,name)>=sizeof(wdir)) {
+		debuga(_("Buffer too small to store %s%s/sarg-users"),dirname,name);
+		exit(EXIT_FAILURE);
+	}
 	if((fp_in=fopen(wdir,"r"))==NULL) {
-		sprintf(wdir,"%s%s/users",dirname,name);
+		if (snprintf(wdir,sizeof(wdir),"%s%s/users",dirname,name)>=sizeof(wdir)) {
+			debuga(_("Buffer too small to store %s%s/users"),dirname,name);
+			exit(EXIT_FAILURE);
+		}
 		if((fp_in=fopen(wdir,"r"))==NULL) {
 			return(0);
 		}
 	}
 
 	if (!fgets(tuser,sizeof(tuser),fp_in)) {
-		debuga(_("Failed to read the number of users in %s\n"),wdir);
+		/* TRANSLATORS: %s is a file name.
+		 */
+		debuga(_("Failed to read the number of users in \"%s\"\n"),wdir);
 		exit(EXIT_FAILURE);
 	}
 	fclose(fp_in);
@@ -736,16 +806,22 @@ void obttotal(const char *dirname, const char *name, int nuser, long long int *t
 	*tbytes=0;
 	*media=0;
 
-	sprintf(wdir,"%s%s/sarg-general",dirname,name);
+	if (snprintf(wdir,sizeof(wdir),"%s%s/sarg-general",dirname,name)>=sizeof(wdir)) {
+		debuga(_("Buffer too small to store %s%s/sarg-general"),dirname,name);
+		exit(EXIT_FAILURE);
+	}
 	if ((fp_in = fopen(wdir, "r")) == 0) {
-		sprintf(wdir,"%s%s/general",dirname,name);
+		if (snprintf(wdir,sizeof(wdir),"%s%s/general",dirname,name)>=sizeof(wdir)) {
+			debuga(_("Buffer too small to store %s%s/general"),dirname,name);
+			exit(EXIT_FAILURE);
+		}
 		if ((fp_in = fopen(wdir, "r")) == 0) {
 			return;
 		}
 	}
 
 	if ((line=longline_create())==NULL) {
-		debuga(_("Not enough memory to read the file %s\n"),wdir);
+		debuga(_("Not enough memory to read file \"%s\"\n"),wdir);
 		exit(EXIT_FAILURE);
 	}
 
@@ -758,17 +834,17 @@ void obttotal(const char *dirname, const char *name, int nuser, long long int *t
 			continue;
 		getword_start(&gwarea,buf);
 		if (getword(user,sizeof(user),&gwarea,sep)<0) {
-			debuga(_("There is a invalid user in file %s\n"),wdir);
+			debuga(_("Invalid user in file \"%s\"\n"),wdir);
 			exit(EXIT_FAILURE);
 		}
 		if(strcmp(user,"TOTAL") != 0)
 			continue;
 		if (getword_skip(MAXLEN,&gwarea,sep)<0) {
-			debuga(_("There a broken total number of access in file %s\n"),wdir);
+			debuga(_("Invalid total number of accesses in file \"%s\"\n"),wdir);
 			exit(EXIT_FAILURE);
 		}
 		if (getword_atoll(tbytes,&gwarea,sep)<0) {
-			debuga(_("There is a broken number of bytes in file %s\n"),wdir);
+			debuga(_("Invalid number of bytes in file \"%s\"\n"),wdir);
 			exit(EXIT_FAILURE);
 		}
 		break;
@@ -923,12 +999,13 @@ static void copy_images(void)
 	struct stat info;
 
 	if (snprintf(images,sizeof(images),"%simages",outdir)>=sizeof(images)) {
-		debuga(_("Cannot copy images to target directory %simages\n"),outdir);
+		debuga(_("Path too long: "));
+		debuga_more("%simages\n",outdir);
 		exit(EXIT_FAILURE);
 	}
 	if (access(images,R_OK)!=0) {
 		if (mkdir(images,0755)) {
-			debuga(_("Cannot create directory %s - %s\n"),images,strerror(errno));
+			debuga(_("Cannot create directory \"%s\": %s\n"),images,strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 	}
@@ -936,35 +1013,41 @@ static void copy_images(void)
 	strcpy(imgdir,IMAGEDIR);
 	dirp = opendir(imgdir);
 	if(dirp==NULL) {
-		debuga(_("(util) Can't open directory %s: %s\n"),imgdir,strerror(errno));
+		debugapos("util",_("Cannot open directory \"%s\": %s\n"),imgdir,strerror(errno));
 		return;
 	}
 	while ((direntp = readdir( dirp )) != NULL ){
 		if(direntp->d_name[0]=='.')
 			continue;
-		sprintf(srcfile,"%s/%s",imgdir,direntp->d_name);
+		if (snprintf(srcfile,sizeof(srcfile),"%s/%s",imgdir,direntp->d_name)>=sizeof(srcfile)) {
+			debuga(_("Buffer too small to store %s/%s"),imgdir,direntp->d_name);
+			exit(EXIT_FAILURE);
+		}
 		if (stat(srcfile,&info)) {
-			debuga(_("Cannot stat \"%s\" - %s\n"),srcfile,strerror(errno));
+			debuga(_("Cannot stat \"%s\": %s\n"),srcfile,strerror(errno));
 			continue;
 		}
 		if (S_ISREG(info.st_mode)) {
-			sprintf(dstfile,"%s/%s",images,direntp->d_name);
+			if (snprintf(dstfile,sizeof(dstfile),"%s/%s",images,direntp->d_name)>=sizeof(dstfile)) {
+				debuga(_("Buffer too small to store %s/%s"),images,direntp->d_name);
+				exit(EXIT_FAILURE);
+			}
 			img_in = fopen(srcfile, "rb");
 			if(img_in!=NULL) {
 				img_ou = fopen(dstfile, "wb");
 				if(img_ou!=NULL) {
 					while ((nread = fread(buffer,1,sizeof(buffer),img_in))>0) {
 						if (fwrite(buffer,1,nread,img_ou)!=nread) {
-							debuga(_("Failed to copy image %s to %s\n"),srcfile,dstfile);
+							debuga(_("Failed to copy image \"%s\" to \"%s\"\n"),srcfile,dstfile);
 							break;
 						}
 					}
 					fclose(img_ou);
 				} else
-					fprintf(stderr,"SARG: (util): %s %s: %s\n", _("Cannot open file")?_("Cannot open file"):"Can't open/create file", dstfile, strerror(errno));
+					debugapos("util",_("Cannot open file \"%s\": %s\n"), dstfile, strerror(errno));
 				fclose(img_in);
 			} else
-				fprintf(stderr,"SARG: (util): %s %s: %s\n", _("Cannot open file")?_("Cannot open file"):"Can't open file", srcfile, strerror(errno));
+				debugapos("util",_("Cannot open file \"%s\": %s\n"),srcfile, strerror(errno));
 		}
 	}
 	(void) closedir(dirp);
@@ -1051,7 +1134,7 @@ int vrfydir(const struct periodstruct *per1, const char *addr, const char *site,
 
 			if(count > 0) {
 				if(debug)
-					debuga(_("File %s already exists, moved to %s\n"),outdirname,wdir);
+					debuga(_("File \"%s\" already exists, moved to \"%s\"\n"),outdirname,wdir);
 				rename(outdirname,wdir);
 			}
 		} else {
@@ -1074,7 +1157,7 @@ int vrfydir(const struct periodstruct *per1, const char *addr, const char *site,
 
 			if(count > 0) {
 				if(debug)
-					debuga(_("File %s already exists, moved to %s\n"),dirname2,wdir);
+					debuga(_("File \"%s\" already exists, moved to \"%s\"\n"),dirname2,wdir);
 				rename(dirname2,wdir);
 				strcpy(dirname2,wdir);
 			}
@@ -1090,9 +1173,12 @@ int vrfydir(const struct periodstruct *per1, const char *addr, const char *site,
 
 	strcpy(dirname2,wdir);
 
-	sprintf(wdir,"%s/sarg-date",outdirname);
+	if (snprintf(wdir,sizeof(wdir),"%s/sarg-date",outdirname)>=sizeof(wdir)) {
+		debuga(_("Buffer too small to store %s/sarg-date"),outdirname);
+		exit(EXIT_FAILURE);
+	}
 	if ((fp_ou = fopen(wdir, "wt")) == 0) {
-		debuga(_("cannot open %s for writing\n"),wdir);
+		debuga(_("Cannot open file \"%s\": %s\n"),wdir,strerror(errno));
 		perror("SARG:");
 		exit(EXIT_FAILURE);
 	}
@@ -1101,12 +1187,12 @@ int vrfydir(const struct periodstruct *per1, const char *addr, const char *site,
 	loctm=localtime(&curtime);
 	strftime(wdir,sizeof(wdir),"%Y-%m-%d %H:%M:%S",loctm);
 	if (fprintf(fp_ou,"%s %d\n",wdir,loctm->tm_isdst)<0) {
-		debuga(_("Failed to write the date in %s\n"),wdir);
+		debuga(_("Failed to write the date in \"%s\"\n"),wdir);
 		perror("SARG:");
 		exit(EXIT_FAILURE);
 	}
 	if (fclose(fp_ou)==EOF) {
-		debuga(_("Failed to write the date in %s\n"),wdir);
+		debuga(_("Failed to close file \"%s\": %s\n"),wdir,strerror(errno));
 		perror("SARG:");
 		exit(EXIT_FAILURE);
 	}
@@ -1174,26 +1260,26 @@ void zdate(char *ftime,int ftimesize, const char *DateFormat)
 
 char *fixtime(long long int elap)
 {
-	int num = elap / 1000;
+	long int num = elap / 1000LL;
 	int hor = 0;
 	int min = 0;
 	int sec = 0;
-	static char buf[12];
+	static char buf[20];
 
-	hor=num / 3600;
-	min=(num % 3600) / 60;
-	sec=num % 60;
+	hor=num / 3600L;
+	min=(num % 3600L) / 60L;
+	sec=num % 60L;
 
 	if(hor==0 && min==0 && sec==0)
 		strcpy(buf,"0");
 	else
-		sprintf(buf,"%d:%02d:%02d",hor,min,sec);
+		snprintf(buf,sizeof(buf),"%d:%02d:%02d",hor,min,sec);
 
 	return buf;
 }
 
 
-void date_from(char *date, int *dfrom, int *duntil)
+void date_from(char *date,int date_size, int *dfrom, int *duntil)
 {
 	int d0=0;
 	int m0=0;
@@ -1328,7 +1414,7 @@ void date_from(char *date, int *dfrom, int *duntil)
 
 	*dfrom=y0*10000+m0*100+d0;
 	*duntil=y1*10000+m1*100+d1;
-	sprintf(date,"%02d/%02d/%04d-%02d/%02d/%04d",d0,m0,y0,d1,m1,y1);
+	snprintf(date,date_size,"%02d/%02d/%04d-%02d/%02d/%04d",d0,m0,y0,d1,m1,y1);
 	return;
 }
 
@@ -1375,16 +1461,17 @@ void removetmp(const char *outdir)
 		debuga(_("Purging temporary file sarg-general\n"));
 	}
 	if (snprintf(filename,sizeof(filename),"%s/sarg-general",outdir)>=sizeof(filename)) {
-		debuga(_("(removetmp) directory too long to remove %s/sarg-period\n"),outdir);
+		debugapos("removetmp",_("Path too long: "));
+		debuga_more("%s/sarg-period\n",outdir);
 		exit(EXIT_FAILURE);
 	}
 	if((fp_gen=fopen(filename,"w"))==NULL){
-		debuga(_("(removetmp) Cannot open file %s\n"),filename);
+		debugapos("removetmp",_("Cannot open file \"%s\": %s\n"),filename,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	totalger(fp_gen,filename);
 	if (fclose(fp_gen)==EOF) {
-		debuga(_("Failed to close %s after writing the total line - %s\n"),filename,strerror(errno));
+		debuga(_("Failed to close file \"%s\": %s\n"),filename,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 }
@@ -1401,27 +1488,27 @@ void load_excludecodes(const char *ExcludeCodes)
 		return;
 
 	if((fp_in=fopen(ExcludeCodes,"r"))==NULL) {
-		debuga(_("(util) Cannot open file %s (exclude_codes)\n"),ExcludeCodes);
+		debugapos("util",_("Cannot open file \"%s\": %s\n"),ExcludeCodes,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if (fseek(fp_in, 0, SEEK_END)==-1) {
-		debuga(_("Failed to move till the end of the excluded codes file %s: %s\n"),ExcludeCodes,strerror(errno));
+		debuga(_("Failed to move till the end of file \"%s\": %s\n"),ExcludeCodes,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	MemSize = ftell(fp_in);
 	if (MemSize<0) {
-		debuga(_("Cannot get the size of file %s\n"),ExcludeCodes);
+		debuga(_("Cannot get the size of file \"%s\": %s\n"),ExcludeCodes,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	if (fseek(fp_in, 0, SEEK_SET)==-1) {
-		debuga(_("Failed to rewind the excluded codes file %s: %s\n"),ExcludeCodes,strerror(errno));
+		debuga(_("Failed to rewind file \"%s\": %s\n"),ExcludeCodes,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	MemSize+=1;
 	if((excludecode=(char *) malloc(MemSize))==NULL) {
-		debuga(_("malloc error (%ld)\n"),MemSize);
+		debuga(_("malloc failed to allocate %ld bytes\n"),MemSize);
 		exit(EXIT_FAILURE);
 	}
 	memset(excludecode,0,MemSize);
@@ -1432,7 +1519,7 @@ void load_excludecodes(const char *ExcludeCodes)
 		for (i=strlen(data)-1 ; i>=0 && (unsigned char)data[i]<=' ' ; i--) data[i]='\0';
 		if (i<0) continue;
 		if (Stored+i+2>=MemSize) {
-			debuga(_("Too many codes to exclude in file %s\n"),ExcludeCodes);
+			debuga(_("Too many codes to exclude in file \"%s\"\n"),ExcludeCodes);
 			break;
 		}
 		strcat(excludecode,data);
@@ -1585,8 +1672,8 @@ char *get_size(const char *path, const char *file)
 	char cmd[255];
 	char *ptr;
 
-	if (snprintf(cmd,sizeof(cmd),"du -skh %s%s",path,file)>=sizeof(cmd)) {
-		debuga(_("Cannot get disk space because the path %s%s is too long\n"),path,file);
+	if (snprintf(cmd,sizeof(cmd),"du -skh \"%s%s\"",path,file)>=sizeof(cmd)) {
+		debuga(_("Cannot get disk space because the path \"%s%s\" is too long\n"),path,file);
 		exit(EXIT_FAILURE);
 	}
 	if ((fp = popen(cmd, "r")) == NULL) {
@@ -1599,7 +1686,10 @@ char *get_size(const char *path, const char *file)
 	}
 	ptr=strchr(response,'\t');
 	if (ptr==NULL) {
-		debuga(_("The command %s failed\n"),cmd);
+		/* TRANSLATORS: First %s is the command to get the occuped disk size (namely, du -skh "...").
+		 * The second %s is the string returned by the command.
+		 */
+		debuga(_("The command to compute the occupied disk size (%s) returned the unknown string %s\n"),cmd,response);
 		exit(EXIT_FAILURE);
 	}
 	pclose(fp);
@@ -1611,10 +1701,14 @@ char *get_size(const char *path, const char *file)
 void show_info(FILE *fp_ou)
 {
 	char ftime[127];
+	char pgmurl[250];
 
 	if(!ShowSargInfo) return;
 	zdate(ftime, sizeof(ftime), DateFormat);
-	fprintf(fp_ou,"<div class=\"info\">%s <a href='%s'>%s-%s</a> %s %s</div>\n",_("Generated by"),URL,PGM,VERSION,_("on"),ftime);
+	fputs("<div class=\"info\">",fp_ou);
+	snprintf(pgmurl,sizeof(pgmurl),"<a href='%s'>%s-%s</a>",URL,PGM,VERSION);
+	fprintf(fp_ou,_("Generated by %s on %s"),pgmurl,ftime);
+	fputs("</div>\n",fp_ou);
 }
 
 void show_sarg(FILE *fp_ou, int depth)
@@ -1783,7 +1877,20 @@ void url_to_file(const char *url,char *file,int filesize)
 
 void version(void)
 {
-	printf(_("SARG Version: %s\n"),VERSION);
+	printf(_("SARG version: %s\n"),VERSION);
+#if defined(ENABLE_NLS) && defined(HAVE_LOCALE_H)
+	if (debug) {
+		printf(_("\nFor the translation to work, a valid message file should be installed as "
+				 "\"%s/<Locale>/LC_MESSAGES/%s.mo\" where <Locale> is derived from the effective locale.\n"),LOCALEDIR,PACKAGE_NAME);
+		if (CurrentLocale) {
+			printf(_("Currently effective locale is \"%s\".\n"),CurrentLocale);
+		} else {
+			printf(_("Locale is not set in the environment variable.\n"));
+		}
+		// TRANSLATORS: You may change this message to tell the reader that the language is correctly supported.
+		printf(_("If this message is in English, then your language is not supported or not correctly installed.\n"));
+	}
+#endif
 	exit(EXIT_SUCCESS);
 }
 
@@ -1815,7 +1922,8 @@ void unlinkdir(const char *dir,bool contentonly)
 		    (direntp->d_name[1] == '.' && direntp->d_name[2] == '\0')))
 			continue;
 		if (snprintf(dname,sizeof(dname),"%s/%s",dir,direntp->d_name)>=sizeof(dname)) {
-			debuga(_("directory name to delete too long: %s/%s\n"),dir,direntp->d_name);
+			debuga(_("Path too long: "));
+			debuga_more("%s/%s\n",dir,direntp->d_name);
 			exit(EXIT_FAILURE);
 		}
 #ifdef HAVE_LSTAT
@@ -1824,7 +1932,7 @@ void unlinkdir(const char *dir,bool contentonly)
 		err=stat(dname,&st);
 #endif
 		if (err) {
-			debuga(_("cannot stat %s\n"),dname);
+			debuga(_("Cannot stat \"%s\": %s\n"),dname,strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 		if (S_ISREG(st.st_mode)) {
@@ -1835,7 +1943,7 @@ void unlinkdir(const char *dir,bool contentonly)
 		} else if (S_ISDIR(st.st_mode)) {
 			unlinkdir(dname,0);
 		} else {
-			debuga(_("unknown path type %s\n"),dname);
+			debuga(_("Unknown path type \"%s\"\n"),dname);
 		}
 	}
 	closedir(dirp);
@@ -1906,7 +2014,8 @@ void emptytmpdir(const char *dir)
 		}
 		
 		if (snprintf(dname,sizeof(dname),"%s/%s",dir,direntp->d_name)>=sizeof(dname)) {
-			debuga(_("directory name to delete too long: %s/%s\n"),dir,direntp->d_name);
+			debuga(_("Path too long: "));
+			debuga_more("%s/%s\n",dir,direntp->d_name);
 			exit(EXIT_FAILURE);
 		}
 		
@@ -1916,7 +2025,7 @@ void emptytmpdir(const char *dir)
 		err=stat(dname,&st);
 #endif
 		if (err) {
-			debuga(_("cannot stat \"%s\"\n"),dname);
+			debuga(_("Cannot stat \"%s\": %s\n"),dname,strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 		if (S_ISDIR(st.st_mode)) {
@@ -1948,7 +2057,8 @@ void emptytmpdir(const char *dir)
 		}
 		
 		if (snprintf(dname,sizeof(dname),"%s/%s",dir,direntp->d_name)>=sizeof(dname)) {
-			debuga(_("directory name to delete too long: %s/%s\n"),dir,direntp->d_name);
+			debuga(_("Path too long: "));
+			debuga_more("%s/%s\n",dir,direntp->d_name);
 			exit(EXIT_FAILURE);
 		}
 #ifdef HAVE_LSTAT
@@ -1957,7 +2067,7 @@ void emptytmpdir(const char *dir)
 		err=stat(dname,&st);
 #endif
 		if (err) {
-			debuga(_("cannot stat \"%s\"\n"),dname);
+			debuga(_("Cannot stat \"%s\": %s\n"),dname,strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 		if (S_ISREG(st.st_mode)) {
@@ -1966,7 +2076,7 @@ void emptytmpdir(const char *dir)
 				exit(EXIT_FAILURE);
 			}
 		} else {
-			debuga(_("unknown path type %s\n"),dname);
+			debuga(_("Unknown path type \"%s\"\n"),dname);
 		}
 	}
 	closedir(dirp);
